@@ -124,6 +124,15 @@
     _allowMP3Passthru = allowMP3Passthru;
 }
 
+- (void)setAllowOpusPassthru:(BOOL)allowOpusPassthru
+{
+    if (allowOpusPassthru != _allowOpusPassthru)
+    {
+        [[self.undo prepareWithInvocationTarget:self] setAllowOpusPassthru:_allowOpusPassthru];
+    }
+    _allowOpusPassthru = allowOpusPassthru;
+}
+
 - (void)setAllowTrueHDPassthru:(BOOL)allowTrueHDPassthru
 {
     if (allowTrueHDPassthru != _allowTrueHDPassthru)
@@ -215,6 +224,7 @@
     self.allowFLACPassthru   = NO;
     self.allowMP2Passthru    = NO;
     self.allowMP3Passthru    = NO;
+    self.allowOpusPassthru   = NO;
     self.allowTrueHDPassthru = NO;
 
     // then, enable allowed passthru encoders
@@ -249,6 +259,9 @@
                 case HB_ACODEC_MP3_PASS:
                     self.allowMP3Passthru = YES;
                     break;
+                case HB_ACODEC_OPUS_PASS:
+                    self.allowOpusPassthru = YES;
+                    break;
                 case HB_ACODEC_TRUEHD_PASS:
                     self.allowTrueHDPassthru = YES;
                     break;
@@ -356,6 +369,10 @@
     {
         [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_MP3_PASS))];
     }
+    if (self.allowOpusPassthru)
+    {
+        [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_OPUS_PASS))];
+    }
     if (self.allowTrueHDPassthru)
     {
         [copyMask addObject:@(hb_audio_encoder_get_short_name(HB_ACODEC_TRUEHD_PASS))];
@@ -370,7 +387,7 @@
 
     preset[@"AudioSecondaryEncoderMode"] = @(self.secondaryEncoderMode);
 
-    NSMutableArray *audioList = [[NSMutableArray alloc] init];
+    NSMutableArray<NSDictionary *> *audioList = [[NSMutableArray alloc] init];
 
     for (HBAudioTrackPreset *track in self.tracksArray)
     {
@@ -379,14 +396,19 @@
         {
             sampleRate = @(hb_audio_samplerate_get_name(track.sampleRate));
         }
-        NSDictionary *newTrack = @{@"AudioEncoder": @(hb_audio_encoder_get_short_name(track.encoder)),
-                                   @"AudioMixdown": @(hb_mixdown_get_short_name(track.mixdown)),
-                                   @"AudioSamplerate": sampleRate,
-                                   @"AudioBitrate": @(track.bitRate),
-                                   @"AudioTrackDRCSlider": @(track.drc),
-                                   @"AudioTrackGainSlider": @(track.gain)};
+        const char *encoderShortName = hb_audio_encoder_get_short_name(track.encoder);
+        const char *mixdownShortName = hb_mixdown_get_short_name(track.mixdown);
+        if (encoderShortName && mixdownShortName)
+        {
+            NSDictionary *newTrack = @{@"AudioEncoder": @(encoderShortName),
+                                       @"AudioMixdown": @(mixdownShortName),
+                                       @"AudioSamplerate": sampleRate,
+                                       @"AudioBitrate": @(track.bitRate),
+                                       @"AudioTrackDRCSlider": @(track.drc),
+                                       @"AudioTrackGainSlider": @(track.gain)};
 
-        [audioList addObject:newTrack];
+            [audioList addObject:newTrack];
+        }
     }
 
     preset[@"AudioList"] = audioList;
@@ -443,6 +465,7 @@
         copy->_allowDTSPassthru = _allowDTSPassthru;
         copy->_allowMP2Passthru = _allowMP2Passthru;
         copy->_allowMP3Passthru = _allowMP3Passthru;
+        copy->_allowOpusPassthru = _allowOpusPassthru;
         copy->_allowTrueHDPassthru = _allowTrueHDPassthru;
         copy->_allowFLACPassthru = _allowFLACPassthru;
 
@@ -477,6 +500,7 @@
     encodeBool(_allowDTSPassthru);
     encodeBool(_allowMP2Passthru);
     encodeBool(_allowMP3Passthru);
+    encodeBool(_allowOpusPassthru);
     encodeBool(_allowTrueHDPassthru);
     encodeBool(_allowFLACPassthru);
 
@@ -505,6 +529,7 @@
     decodeBool(_allowDTSPassthru);
     decodeBool(_allowMP2Passthru);
     decodeBool(_allowMP3Passthru);
+    decodeBool(_allowOpusPassthru);
     decodeBool(_allowTrueHDPassthru);
     decodeBool(_allowFLACPassthru);
 
