@@ -297,7 +297,7 @@ static HBMixdownTransformer    *mixdownTransformer;
     [attrString appendString:@"\t"                          withAttributes:detailAttr];
     [attrString appendString:HBKitLocalizedString(@"Destination:", @"Destination description") withAttributes:detailBoldAttr];
     [attrString appendString:@" \t"                         withAttributes:detailAttr];
-    [attrString appendString:self.completeOutputURL.path    withAttributes:detailAttr];
+    [attrString appendString:self.destinationURL.path    withAttributes:detailAttr];
     [attrString appendString:@"\n"                          withAttributes:detailAttr];
 
     return attrString;
@@ -338,7 +338,7 @@ static HBMixdownTransformer    *mixdownTransformer;
     }
     else if (![filters.deinterlace isEqualToString:@"off"])
     {
-        // Deinterlace or Decomb
+        // Deinterlace filters
         NSString *type =  [[[HBFilters deinterlaceTypesDict] allKeysForObject:filters.deinterlace] firstObject];
 
         if ([filters.deinterlacePreset isEqualToString:@"custom"])
@@ -353,7 +353,11 @@ static HBMixdownTransformer    *mixdownTransformer;
             }
             else if ([filters.deinterlace isEqualToString:@"deinterlace"])
             {
-                [summary appendFormat:@", %@ (%@)", type, [[[HBFilters deinterlacePresetsDict] allKeysForObject:filters.deinterlacePreset] firstObject]];
+                [summary appendFormat:@", %@ (%@)", type, [[[HBFilters yadifPresetsDict] allKeysForObject:filters.deinterlacePreset] firstObject]];
+            }
+            else if ([filters.deinterlace isEqualToString:@"bwdif"])
+            {
+                [summary appendFormat:@", %@ (%@)", type, [[[HBFilters bwdifPresetsDict] allKeysForObject:filters.deinterlacePreset] firstObject]];
             }
         }
     }
@@ -631,6 +635,12 @@ static HBMixdownTransformer    *mixdownTransformer;
                 }
             }
 
+            if (audioTrack.title.length)
+            {
+                [detailString appendString:@", "];
+                [detailString appendFormat:HBKitLocalizedString(@"Title: %@", @"Audio track title description"), audioTrack.title];
+            }
+
             [attrString appendString:@"\t" withAttributes: detailAttr];
             if (secondLine)
             {
@@ -667,6 +677,12 @@ static HBMixdownTransformer    *mixdownTransformer;
             // remember that index 0 of Subtitles can contain "Foreign Audio Search
             [detailString appendString:self.subtitles.sourceTracks[track.sourceTrackIdx].displayName];
 
+            if (track.title.length)
+            {
+                [detailString appendString:@", "];
+                [detailString appendFormat:HBKitLocalizedString(@"Title: %@", @"Subtitles track title description"), track.title];
+            }
+
             if (track.forcedOnly)
             {
                 [detailString appendString:@", "];
@@ -952,7 +968,7 @@ static HBMixdownTransformer    *mixdownTransformer;
     // Deinterlace
     if (![filters.deinterlace isEqualToString:@"off"])
     {
-        // Deinterlace or Decomb
+        // Deinterlace filters
         NSString *type = [[[HBFilters deinterlaceTypesDict] allKeysForObject:filters.deinterlace] firstObject];
         if (type)
         {
