@@ -1,10 +1,8 @@
-//
-//  HBSecurityAccessToken.m
-//  HandBrake
-//
-//  Created by Damiano Galassi on 24/01/17.
-//
-//
+/*  HBSecurityAccessToken.m $
+
+ This file is part of the HandBrake source code.
+ Homepage: <http://handbrake.fr/>.
+ It may be used under the terms of the GNU General Public License. */
 
 #import "HBSecurityAccessToken.h"
 
@@ -15,7 +13,7 @@
 
 @implementation HBSecurityAccessToken
 
-- (instancetype)initWithObject:(id<HBSecurityScope>)object;
+- (instancetype)initWithObject:(id<HBSecurityScope>)object
 {
     self = [super init];
     if (self)
