@@ -15,27 +15,24 @@ namespace HandBrake.Interop.Interop
     using System.Linq;
     using System.Runtime.ExceptionServices;
     using System.Runtime.InteropServices;
+    using System.Text.Json;
     using System.Timers;
 
-    using HandBrake.Interop.Interop.EventArgs;
-    using HandBrake.Interop.Interop.Factories;
     using HandBrake.Interop.Interop.HbLib;
-    using HandBrake.Interop.Interop.HbLib.Wrappers.Interfaces;
     using HandBrake.Interop.Interop.Helpers;
     using HandBrake.Interop.Interop.Interfaces;
+    using HandBrake.Interop.Interop.Interfaces.EventArgs;
+    using HandBrake.Interop.Interop.Interfaces.Model;
+    using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
+    using HandBrake.Interop.Interop.Interfaces.Model.Picture;
+    using HandBrake.Interop.Interop.Interfaces.Model.Preview;
     using HandBrake.Interop.Interop.Json.Encode;
     using HandBrake.Interop.Interop.Json.Scan;
     using HandBrake.Interop.Interop.Json.State;
-    using HandBrake.Interop.Interop.Model.Encoding;
-    using HandBrake.Interop.Interop.Model.Preview;
-    using HandBrake.Interop.Interop.Providers;
-    using HandBrake.Interop.Interop.Providers.Interfaces;
-
-    using Newtonsoft.Json;
+    using HandBrake.Interop.Utilities;
 
     public class HandBrakeInstance : IHandBrakeInstance, IDisposable
     {
-        private IHbFunctions hbFunctions;
         private const double ScanPollIntervalMs = 250;
         private const double EncodePollIntervalMs = 250;
         private Timer scanPollTimer;
@@ -73,11 +70,6 @@ namespace HandBrake.Interop.Interop
         /// </summary>
         public event EventHandler<EncodeCompletedEventArgs> EncodeCompleted;
 
-        /// <summary>
-        /// Gets the handle.
-        /// </summary>
-        internal IntPtr Handle { get; private set; }
-
         /// <summary>
         /// Gets the number of previews created during scan.
         /// </summary>
@@ -101,12 +93,19 @@ namespace HandBrake.Interop.Interop
         /// <summary>
         /// Gets the HandBrake version string.
         /// </summary>
-        public string Version => Marshal.PtrToStringAnsi(hbFunctions.hb_get_version(this.Handle));
+        public string Version => Marshal.PtrToStringAnsi(HBFunctions.hb_get_version(this.Handle));
 
         /// <summary>
         /// Gets the HandBrake build number.
         /// </summary>
-        public int Build => hbFunctions.hb_get_build(this.Handle);
+        public int Build => HBFunctions.hb_get_build(this.Handle);
+
+        public bool IsRemoteInstance => false;
+
+        /// <summary>
+        /// Gets the handle.
+        /// </summary>
+        internal IntPtr Handle { get; private set; }
 
         /// <summary>
         /// Initializes this instance.
@@ -119,13 +118,10 @@ namespace HandBrake.Interop.Interop
         /// </param>
         public void Initialize(int verbosity, bool noHardware)
         {
-            IHbFunctionsProvider hbFunctionsProvider = new HbFunctionsProvider();
-            hbFunctions = hbFunctionsProvider.GetHbFunctionsWrapper();
-
             HandBrakeUtils.EnsureGlobalInit(noHardware);
 
             HandBrakeUtils.RegisterLogger();
-            this.Handle = hbFunctions.hb_init(verbosity, update_check: 0);
+            this.Handle = HBFunctions.hb_init(verbosity, update_check: 0);
         }
 
         /// <summary>
@@ -148,7 +144,7 @@ namespace HandBrake.Interop.Interop
             this.PreviewCount = previewCount;
 
             IntPtr pathPtr = InteropUtilities.ToUtf8PtrFromString(path);
-            hbFunctions.hb_scan(this.Handle, pathPtr, titleIndex, previewCount, 1, (ulong)(minDuration.TotalSeconds * 90000));
+            HBFunctions.hb_scan(this.Handle, pathPtr, titleIndex, previewCount, 1, (ulong)(minDuration.TotalSeconds * 90000));
             Marshal.FreeHGlobal(pathPtr);
 
             this.scanPollTimer = new Timer();
@@ -173,11 +169,10 @@ namespace HandBrake.Interop.Interop
         /// <summary>
         /// Stops an ongoing scan.
         /// </summary>
-        [HandleProcessCorruptedStateExceptions]
         public void StopScan()
         {
             this.scanPollTimer.Stop();
-            hbFunctions.hb_scan_stop(this.Handle);
+            HBFunctions.hb_scan_stop(this.Handle);
         }
 
         /// <summary>
@@ -192,43 +187,20 @@ namespace HandBrake.Interop.Interop
         /// <param name="previewNumber">
         /// The index of the preview to get (0-based).
         /// </param>
-        /// <param name="deinterlace">
-        /// True to enable basic deinterlace of preview images.
-        /// </param>
         /// <returns>
         /// An image with the requested preview.
         /// </returns>
-        [HandleProcessCorruptedStateExceptions]
-        public RawPreviewData GetPreview(PreviewSettings settings, int previewNumber, bool deinterlace)
+        public RawPreviewData GetPreview(JsonEncodeObject settings, int previewNumber)
         {
-            SourceTitle title = this.Titles.TitleList.FirstOrDefault(t => t.Index == settings.TitleNumber);
-
-            // Create the Expected Output Geometry details for libhb.
-            hb_geometry_settings_s uiGeometry = new hb_geometry_settings_s
-            {
-                crop = new[] { settings.Cropping.Top, settings.Cropping.Bottom, settings.Cropping.Left, settings.Cropping.Right },
-                itu_par = 0,
-                keep = (int)AnamorphicFactory.KeepSetting.HB_KEEP_WIDTH + (settings.KeepDisplayAspect ? 0x04 : 0), // TODO Keep Width?
-                maxWidth = settings.MaxWidth,
-                maxHeight = settings.MaxHeight,
-                mode = (int)(hb_anamorphic_mode_t)settings.Anamorphic,
-                modulus = settings.Modulus ?? 16,
-                geometry = new hb_geometry_s
-                {
-                    height = settings.Height,
-                    width = settings.Width,
-                    par = new hb_rational_t { den = settings.PixelAspectY, num = settings.PixelAspectX }
-                }
-            };
-
             // Fetch the image data from LibHb
-            IntPtr resultingImageStuct = hbFunctions.hb_get_preview2(this.Handle, settings.TitleNumber, previewNumber, ref uiGeometry, deinterlace ? 1 : 0);
-            hb_image_s image = InteropUtilities.ToStructureFromPtr<hb_image_s>(resultingImageStuct);
+            string taskJson = JsonSerializer.Serialize(settings, JsonSettings.Options);
+            IntPtr resultingImageStruct = HBFunctions.hb_get_preview3_json(this.Handle, previewNumber, taskJson);
+            hb_image_s image = InteropUtilities.ToStructureFromPtr<hb_image_s>(resultingImageStruct);
 
             // Copy the filled image buffer to a managed array.
             int stride_width = image.plane[0].stride;
             int stride_height = image.plane[0].height_stride;
-            int imageBufferSize = stride_width * stride_height;  // int imageBufferSize = outputWidth * outputHeight * 4;
+            int imageBufferSize = stride_width * stride_height;
 
             byte[] managedBuffer = new byte[imageBufferSize];
             Marshal.Copy(image.plane[0].data, managedBuffer, 0, imageBufferSize);
@@ -237,8 +209,8 @@ namespace HandBrake.Interop.Interop
 
             // Close the image so we don't leak memory.
             IntPtr nativeJobPtrPtr = Marshal.AllocHGlobal(Marshal.SizeOf(typeof(IntPtr)));
-            Marshal.WriteIntPtr(nativeJobPtrPtr, resultingImageStuct);
-            hbFunctions.hb_image_close(nativeJobPtrPtr);
+            Marshal.WriteIntPtr(nativeJobPtrPtr, resultingImageStruct);
+            HBFunctions.hb_image_close(nativeJobPtrPtr);
             Marshal.FreeHGlobal(nativeJobPtrPtr);
 
             return preview;
@@ -253,7 +225,7 @@ namespace HandBrake.Interop.Interop
         /// <returns>True if DRC can be applied to the track with the given encoder.</returns>
         public bool CanApplyDrc(int trackNumber, HBAudioEncoder encoder, int title)
         {
-            return hbFunctions.hb_audio_can_apply_drc2(this.Handle, title, trackNumber, encoder.Id) > 0;
+            return HBFunctions.hb_audio_can_apply_drc2(this.Handle, title, trackNumber, encoder.Id) > 0;
         }
 
         /// <summary>
@@ -262,15 +234,9 @@ namespace HandBrake.Interop.Interop
         /// <param name="encodeObject">
         /// The encode Object.
         /// </param>
-        [HandleProcessCorruptedStateExceptions]
         public void StartEncode(JsonEncodeObject encodeObject)
         {
-            JsonSerializerSettings settings = new JsonSerializerSettings
-            {
-                NullValueHandling = NullValueHandling.Ignore,
-            };
-
-            string encode = JsonConvert.SerializeObject(encodeObject, Formatting.Indented, settings);
+            string encode = JsonSerializer.Serialize(encodeObject, JsonSettings.Options);
             this.StartEncode(encode);
         }
 
@@ -278,11 +244,10 @@ namespace HandBrake.Interop.Interop
         /// Starts an encode with the given job JSON.
         /// </summary>
         /// <param name="encodeJson">The JSON for the job to start.</param>
-        [HandleProcessCorruptedStateExceptions]
         public void StartEncode(string encodeJson)
         {
-            hbFunctions.hb_add_json(this.Handle, InteropUtilities.ToUtf8PtrFromString(encodeJson));
-            hbFunctions.hb_start(this.Handle);
+            HBFunctions.hb_add_json(this.Handle, InteropUtilities.ToUtf8PtrFromString(encodeJson));
+            HBFunctions.hb_start(this.Handle);
 
             this.encodePollTimer = new Timer();
             this.encodePollTimer.Interval = EncodePollIntervalMs;
@@ -304,41 +269,38 @@ namespace HandBrake.Interop.Interop
         /// <summary>
         /// Pauses the current encode.
         /// </summary>
-        [HandleProcessCorruptedStateExceptions]
         public void PauseEncode()
         {
-            hbFunctions.hb_pause(this.Handle);
+            HBFunctions.hb_pause(this.Handle);
         }
 
         /// <summary>
         /// Resumes a paused encode.
         /// </summary>
-        [HandleProcessCorruptedStateExceptions]
         public void ResumeEncode()
         {
-            hbFunctions.hb_resume(this.Handle);
+            HBFunctions.hb_resume(this.Handle);
         }
 
         /// <summary>
         /// Stops the current encode.
         /// </summary>
-        [HandleProcessCorruptedStateExceptions]
         public void StopEncode()
         {
-            hbFunctions.hb_stop(this.Handle);
+            HBFunctions.hb_stop(this.Handle);
 
             // Also remove all jobs from the queue (in case we stopped a 2-pass encode)
             var currentJobs = new List<IntPtr>();
 
-            int jobs = hbFunctions.hb_count(this.Handle);
+            int jobs = HBFunctions.hb_count(this.Handle);
             for (int i = 0; i < jobs; i++)
             {
-                currentJobs.Add(hbFunctions.hb_job(this.Handle, 0));
+                currentJobs.Add(HBFunctions.hb_job(this.Handle, 0));
             }
 
             foreach (IntPtr job in currentJobs)
             {
-                hbFunctions.hb_rem(this.Handle, job);
+                HBFunctions.hb_rem(this.Handle, job);
             }
         }
 
@@ -348,13 +310,12 @@ namespace HandBrake.Interop.Interop
         /// <returns>
         /// The <see cref="JsonState"/>.
         /// </returns>
-        [HandleProcessCorruptedStateExceptions]
         public JsonState GetEncodeProgress()
         {
-            IntPtr json = hbFunctions.hb_get_state_json(this.Handle);
+            IntPtr json = HBFunctions.hb_get_state_json(this.Handle);
             string statusJson = Marshal.PtrToStringAnsi(json);
 
-            JsonState state = JsonConvert.DeserializeObject<JsonState>(statusJson);
+            JsonState state = JsonSerializer.Deserialize<JsonState>(statusJson, JsonSettings.Options);
             return state;
         }
 
@@ -399,7 +360,7 @@ namespace HandBrake.Interop.Interop
             // Free unmanaged objects.
             IntPtr handlePtr = Marshal.AllocHGlobal(Marshal.SizeOf(typeof(IntPtr)));
             Marshal.WriteIntPtr(handlePtr, this.Handle);
-            hbFunctions.hb_close(handlePtr);
+            HBFunctions.hb_close(handlePtr);
             Marshal.FreeHGlobal(handlePtr);
 
             this.disposed = true;
@@ -408,15 +369,14 @@ namespace HandBrake.Interop.Interop
         /// <summary>
         /// Checks the status of the ongoing scan.
         /// </summary>
-        [HandleProcessCorruptedStateExceptions]
         private void PollScanProgress()
         {
-            IntPtr json = hbFunctions.hb_get_state_json(this.Handle);
+            IntPtr json = HBFunctions.hb_get_state_json(this.Handle);
             string statusJson = Marshal.PtrToStringAnsi(json);
             JsonState state = null;
             if (!string.IsNullOrEmpty(statusJson))
             {
-                state = JsonConvert.DeserializeObject<JsonState>(statusJson);
+                state = JsonSerializer.Deserialize<JsonState>(statusJson, JsonSettings.Options);
             }
 
             TaskState taskState = state != null ? TaskState.FromRepositoryValue(state.State) : null;
@@ -432,12 +392,12 @@ namespace HandBrake.Interop.Interop
             {
                 this.scanPollTimer.Stop();
 
-                var jsonMsg = hbFunctions.hb_get_title_set_json(this.Handle);
+                var jsonMsg = HBFunctions.hb_get_title_set_json(this.Handle);
                 this.TitlesJson = InteropUtilities.ToStringFromUtf8Ptr(jsonMsg);
 
                 if (!string.IsNullOrEmpty(this.TitlesJson))
                 { 
-                    this.Titles = JsonConvert.DeserializeObject<JsonScanObject>(this.TitlesJson);
+                    this.Titles = JsonSerializer.Deserialize<JsonScanObject>(this.TitlesJson, JsonSettings.Options);
                     if (this.Titles != null)
                     {
                         this.FeatureTitle = this.Titles.MainFeature;
@@ -454,13 +414,12 @@ namespace HandBrake.Interop.Interop
         /// <summary>
         /// Checks the status of the ongoing encode.
         /// </summary>
-        [HandleProcessCorruptedStateExceptions]
         private void PollEncodeProgress()
         {
-            IntPtr json = hbFunctions.hb_get_state_json(this.Handle);
+            IntPtr json = HBFunctions.hb_get_state_json(this.Handle);
             string statusJson = Marshal.PtrToStringAnsi(json);
 
-            JsonState state = JsonConvert.DeserializeObject<JsonState>(statusJson);
+            JsonState state = JsonSerializer.Deserialize<JsonState>(statusJson, JsonSettings.Options);
 
             TaskState taskState = state != null ? TaskState.FromRepositoryValue(state.State) : null;
 
@@ -490,7 +449,7 @@ namespace HandBrake.Interop.Interop
                 {
                     this.EncodeCompleted(
                         this,
-                        new EncodeCompletedEventArgs(state.WorkDone.Error != (int)hb_error_code.HB_ERROR_NONE));
+                        new EncodeCompletedEventArgs(state.WorkDone.Error));
                 }
             }
         }
