@@ -9,11 +9,9 @@
 
 namespace HandBrake.Interop.Interop.Json.Presets
 {
+    using System;
     using System.Collections.Generic;
 
-    /// <summary>
-    ///     The preset.
-    /// </summary>
     public class HBPreset
     {
         public bool AlignAVStart { get; set; }
@@ -89,9 +87,9 @@ namespace HandBrake.Interop.Interop.Json.Presets
         public bool Mp4iPodCompatible { get; set; }
 
         /// <summary>
-        /// Gets or sets a value indicating whether picture auto crop.
+        /// Gets or sets a value indicating whether picture loose crop.
         /// </summary>
-        public bool PictureAutoCrop { get; set; }
+        public int PictureCropMode { get; set; }
 
         /// <summary>
         /// Gets or sets the picture bottom crop.
@@ -207,11 +205,6 @@ namespace HandBrake.Interop.Interop.Json.Presets
         /// </summary>
         public bool PictureKeepRatio { get; set; }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether picture loose crop.
-        /// </summary>
-        public bool PictureLooseCrop { get; set; }
-
         /// <summary>
         /// Gets or sets the picture par.
         /// </summary>
@@ -393,16 +386,6 @@ namespace HandBrake.Interop.Interop.Json.Presets
         /// </summary>
         public double VideoQualitySlider { get; set; }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether video qsv decode.
-        /// </summary>
-        public bool VideoQSVDecode { get; set; }
-
-        /// <summary>
-        /// Gets or sets the video qsv async depth.
-        /// </summary>
-        public int VideoQSVAsyncDepth { get; set; }
-
         /// <summary>
         /// Gets or sets a value indicating whether video two pass.
         /// </summary>
