@@ -1,5 +1,5 @@
 ﻿// --------------------------------------------------------------------------------------------------------------------
-// <copyright file="SourceAudioTrack.cs" company="HandBrake Project (http://handbrake.fr)">
+// <copyright file="SourceAudioTrack.cs" company="HandBrake Project (https://handbrake.fr)">
 //   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
 // </copyright>
 // <summary>
@@ -14,6 +14,11 @@ namespace HandBrake.Interop.Interop.Json.Scan
     /// </summary>
     public class SourceAudioTrack
     {
+        /// <summary>
+        /// Gets or sets the track number (1-based).
+        /// </summary>
+        public int TrackNumber { get; set; }
+
         /// <summary>
         /// Gets or sets the bit rate.
         /// </summary>
