@@ -12,8 +12,7 @@ namespace HandBrakeWPF.Commands
     using System;
     using System.Windows.Input;
 
-    using Caliburn.Micro;
-
+    using HandBrakeWPF.Helpers;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     public class OpenPresetManagerCommand : ICommand
@@ -28,7 +27,7 @@ namespace HandBrakeWPF.Commands
 
         public void Execute(object? parameter)
         {
-            IMainViewModel viewModel = IoC.Get<IMainViewModel>();
+            IMainViewModel viewModel = IoCHelper.Get<IMainViewModel>();
             viewModel.OpenPresetWindow();
         }
 
