@@ -13,21 +13,18 @@ namespace HandBrakeWPF.Services.Encode.Factories
     using System.Collections.Generic;
     using System.Globalization;
     using System.Linq;
-    using System.Runtime.InteropServices;
+    using System.Text.Json;
 
+    using HandBrake.App.Core.Utilities;
     using HandBrake.Interop.Interop;
     using HandBrake.Interop.Interop.HbLib;
-    using HandBrake.Interop.Interop.HbLib.Wrappers.Interfaces;
+    using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
     using HandBrake.Interop.Interop.Json.Encode;
     using HandBrake.Interop.Interop.Json.Shared;
-    using HandBrake.Interop.Interop.Model.Encoding;
-    using HandBrake.Interop.Model;
 
-    using HandBrakeWPF.Utilities;
+    using HandBrakeWPF.Model.Filters;
+    using HandBrakeWPF.Services.Interfaces;
 
-    using Newtonsoft.Json.Linq;
-
-    using AudioEncoder = Model.Models.AudioEncoder;
     using AudioEncoderRateType = Model.Models.AudioEncoderRateType;
     using AudioTrack = Model.Models.AudioTrack;
     using ChapterMarker = Model.Models.ChapterMarker;
@@ -35,10 +32,10 @@ namespace HandBrakeWPF.Services.Encode.Factories
     using FramerateMode = Model.Models.FramerateMode;
     using OutputFormat = Model.Models.OutputFormat;
     using PointToPointMode = Model.Models.PointToPointMode;
+    using Range = HandBrake.Interop.Interop.Json.Encode.Range;
     using Subtitle = HandBrake.Interop.Interop.Json.Encode.Subtitles;
     using SubtitleTrack = Model.Models.SubtitleTrack;
-    using SystemInfo = HandBrake.Interop.Utilities.SystemInfo;
-    using Validate = Helpers.Validate;
+    using VideoEncodeRateType = HandBrakeWPF.Model.Video.VideoEncodeRateType;
 
     /// <summary>
     /// This factory takes the internal EncodeJob object and turns it into a set of JSON models
@@ -46,57 +43,32 @@ namespace HandBrakeWPF.Services.Encode.Factories
     /// </summary>
     internal class EncodeTaskFactory
     {
-        // TODO make this non-static
-        private static IHbFunctions hbFunctions;
+        private readonly IUserSettingService userSettingService;
 
-        /// <summary>
-        /// The create.
-        /// </summary>
-        /// <param name="job">
-        /// The encode job.
-        /// </param>
-        /// <param name="configuration">
-        /// The configuration.
-        /// </param>
-        /// <param name="hbFunctionsWrapper">
-        /// An instance of IHbFunctions
-        /// </param>
-        /// <returns>
-        /// The <see cref="JsonEncodeObject"/>.
-        /// </returns>
-        internal static JsonEncodeObject Create(EncodeTask job, HBConfiguration configuration, IHbFunctions hbFunctionsWrapper)
+        public EncodeTaskFactory(IUserSettingService userSettingService)
         {
-            hbFunctions = hbFunctionsWrapper;
+            this.userSettingService = userSettingService;
+        }
 
+        internal JsonEncodeObject Create(EncodeTask job)
+        {
             JsonEncodeObject encode = new JsonEncodeObject
-            {
-                SequenceID = 0,
-                Audio = CreateAudio(job),
-                Destination = CreateDestination(job),
-                Filters = CreateFilters(job),
-                PAR = CreatePAR(job),
-                Metadata = CreateMetadata(job),
-                Source = CreateSource(job, configuration),
-                Subtitle = CreateSubtitle(job),
-                Video = CreateVideo(job, configuration)
-            };
+                                      {
+                                          SequenceID = 0,
+                                          Audio = CreateAudio(job),
+                                          Destination = CreateDestination(job),
+                                          Filters = CreateFilters(job),
+                                          PAR = CreatePAR(job),
+                                          Metadata = CreateMetadata(job),
+                                          Source = CreateSource(job),
+                                          Subtitle = CreateSubtitle(job),
+                                          Video = CreateVideo(job)
+                                      };
 
             return encode;
         }
 
-        /// <summary>
-        /// The create source.
-        /// </summary>
-        /// <param name="job">
-        /// The job.
-        /// </param>
-        /// <param name="configuration">
-        /// The configuration.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Source"/>.
-        /// </returns>
-        private static Source CreateSource(EncodeTask job, HBConfiguration configuration)
+        private Source CreateSource(EncodeTask job)
         {
             Range range = new Range();
             switch (job.PointToPointMode)
@@ -119,7 +91,7 @@ namespace HandBrakeWPF.Services.Encode.Factories
                 case PointToPointMode.Preview:
                     range.Type = "preview";
                     range.Start = job.PreviewEncodeStartAt;
-                    range.SeekPoints = configuration.PreviewScanCount;
+                    range.SeekPoints = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount);
                     range.End = job.PreviewEncodeDuration * 90000;
                     break;
             }
@@ -133,24 +105,15 @@ namespace HandBrakeWPF.Services.Encode.Factories
             };
             return source;
         }
-
-        /// <summary>
-        /// The create destination.
-        /// </summary>
-        /// <param name="job">
-        /// The job.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Destination"/>.
-        /// </returns>
-        private static Destination CreateDestination(EncodeTask job)
+        
+        private Destination CreateDestination(EncodeTask job)
         {
             Destination destination = new Destination
             {
                 File = job.Destination,
                 Mp4Options = new Mp4Options
                 {
-                    IpodAtom = job.IPod5GSupport,
+                    IpodAtom = job.VideoEncoder.IsH264 ? job.IPod5GSupport : false,
                     Mp4Optimize = job.OptimizeMP4
                 },
                 ChapterMarkers = job.IncludeChapterMarkers,
@@ -171,30 +134,12 @@ namespace HandBrakeWPF.Services.Encode.Factories
             return destination;
         }
 
-        /// <summary>
-        /// Create the PAR object
-        /// </summary>
-        /// <param name="job">
-        /// The Job
-        /// </param>
-        /// <returns>
-        /// The produced PAR object.
-        /// </returns>
-        private static PAR CreatePAR(EncodeTask job)
+        private PAR CreatePAR(EncodeTask job)
         {
             return new PAR { Num = job.PixelAspectX, Den = job.PixelAspectY };
         }
 
-        /// <summary>
-        /// The create subtitle.
-        /// </summary>
-        /// <param name="job">
-        /// The job.
-        /// </param>
-        /// <returns>
-        /// The <see cref="HandBrake.Interop.Interop.Json.Encode.Subtitles"/>.
-        /// </returns>
-        private static Subtitle CreateSubtitle(EncodeTask job)
+        private Subtitle CreateSubtitle(EncodeTask job)
         {
             Subtitles subtitle = new Subtitles
             {
@@ -248,7 +193,7 @@ namespace HandBrakeWPF.Services.Encode.Factories
                         Import =
                             new SubImport
                             {
-                                Format = item.SrtPath.EndsWith("srt") ? "SRT" : "SSA",
+                                Format = item.SrtPath.EndsWith("srt", StringComparison.InvariantCultureIgnoreCase) ? "SRT" : "SSA",
                                 Filename = item.SrtPath,
                                 Codeset = item.SrtCharCode,
                                 Language = item.SrtLangCode
@@ -262,31 +207,16 @@ namespace HandBrakeWPF.Services.Encode.Factories
             return subtitle;
         }
 
-        /// <summary>
-        /// The create video.
-        /// </summary>
-        /// <param name="job">
-        /// The job.
-        /// </param>
-        /// <param name="configuration">
-        /// The configuration.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Video"/>.
-        /// </returns>
-        private static Video CreateVideo(EncodeTask job, HBConfiguration configuration)
+        private Video CreateVideo(EncodeTask job)
         {
             Video video = new Video();
 
-            HBVideoEncoder videoEncoder = HandBrakeEncoderHelpers.VideoEncoders.FirstOrDefault(e => e.ShortName == EnumHelper<VideoEncoder>.GetShortName(job.VideoEncoder));
-            Validate.NotNull(videoEncoder, "Video encoder " + job.VideoEncoder + " not recognized.");
-            if (videoEncoder != null)
+            if (job.VideoEncoder != null)
             {
-                video.Encoder = videoEncoder.ShortName;
+                video.Encoder = job.VideoEncoder.ShortName;
             }
 
             video.Level = job.VideoLevel?.ShortName;
-            video.Options = job.ExtraAdvancedArguments;
             video.Preset = job.VideoPreset?.ShortName;
             video.Profile = job.VideoProfile?.ShortName;
 
@@ -300,7 +230,7 @@ namespace HandBrakeWPF.Services.Encode.Factories
 
             if (job.VideoEncodeRateType == VideoEncodeRateType.ConstantQuality)
             {
-                video.Quality = job.Quality;
+                video.Quality = (decimal?)job.Quality;
             }
 
             if (job.VideoEncodeRateType == VideoEncodeRateType.AverageBitrate)
@@ -310,54 +240,65 @@ namespace HandBrakeWPF.Services.Encode.Factories
                 video.Turbo = job.TurboFirstPass;
             }
 
-            video.QSV.Decode = SystemInfo.IsQsvAvailable && configuration.EnableQuickSyncDecoding;
 
-            // The use of the QSV decoder is configurable for non QSV encoders.
-            if (video.QSV.Decode && job.VideoEncoder != VideoEncoder.QuickSync && job.VideoEncoder != VideoEncoder.QuickSyncH265 && job.VideoEncoder != VideoEncoder.QuickSyncH26510b)
+            bool enableQuickSyncDecoding = userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncDecoding);
+            bool useQSVDecodeForNonQSVEnc = userSettingService.GetUserSetting<bool>(UserSettingConstants.UseQSVDecodeForNonQSVEnc);
+            bool enableQsvLowPower = userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncLowPower);
+
+            if (job.VideoEncoder?.IsQuickSync ?? false)
             {
-                video.QSV.Decode = configuration.UseQSVDecodeForNonQSVEnc;
+                video.QSV.Decode = HandBrakeHardwareEncoderHelper.IsQsvAvailable && enableQuickSyncDecoding;
+            }
+
+            // Allow use of the QSV decoder is configurable for non QSV encoders.
+            if (!job.VideoEncoder.IsHardwareEncoder && useQSVDecodeForNonQSVEnc)
+            {
+                video.QSV.Decode = HandBrakeHardwareEncoderHelper.IsQsvAvailable && useQSVDecodeForNonQSVEnc;
+            }
+
+            video.Options = job.ExtraAdvancedArguments;
+
+            if (HandBrakeHardwareEncoderHelper.IsQsvAvailable && (HandBrakeHardwareEncoderHelper.QsvHardwareGeneration > 6) && job.VideoEncoder.IsQuickSync)
+            {
+                if (enableQsvLowPower && !video.Options.Contains("lowpower"))
+                {
+                    video.Options = string.IsNullOrEmpty(video.Options) ? "lowpower=1" : string.Concat(video.Options, ":lowpower=1");
+                }
+                else if(!enableQsvLowPower && !video.Options.Contains("lowpower"))
+                {
+                    video.Options = string.IsNullOrEmpty(video.Options) ? "lowpower=0" : string.Concat(video.Options, ":lowpower=0");
+                }
+            }
+
+            if (this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableNvDecSupport) && job.VideoEncoder.IsNVEnc)
+            {
+                video.HardwareDecode = (int)NativeConstants.HB_DECODE_SUPPORT_NVDEC;
             }
 
             return video;
         }
 
-        /// <summary>
-        /// The create audio.
-        /// </summary>
-        /// <param name="job">
-        /// The job.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Audio"/>.
-        /// </returns>
-        private static Audio CreateAudio(EncodeTask job)
+        private Audio CreateAudio(EncodeTask job)
         {
             Audio audio = new Audio();
 
             List<string> copyMaskList = new List<string>();
-            if (job.AllowedPassthruOptions.AudioAllowAACPass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.AacPassthru));
-            if (job.AllowedPassthruOptions.AudioAllowAC3Pass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.Ac3Passthrough));
-            if (job.AllowedPassthruOptions.AudioAllowDTSHDPass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.DtsHDPassthrough));
-            if (job.AllowedPassthruOptions.AudioAllowDTSPass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.DtsPassthrough));
-            if (job.AllowedPassthruOptions.AudioAllowEAC3Pass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.EAc3Passthrough));
-            if (job.AllowedPassthruOptions.AudioAllowFlacPass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.FlacPassthru));
-            if (job.AllowedPassthruOptions.AudioAllowMP3Pass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.Mp3Passthru));
-            if (job.AllowedPassthruOptions.AudioAllowTrueHDPass) copyMaskList.Add(EnumHelper<AudioEncoder>.GetShortName(AudioEncoder.TrueHDPassthrough));
+            foreach (var item in job.AudioPassthruOptions)
+            {
+                copyMaskList.Add(item.ShortName);
+            }
+
             audio.CopyMask = copyMaskList.ToArray();
 
-            HBAudioEncoder audioEncoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(job.AllowedPassthruOptions.AudioEncoderFallback));
-            audio.FallbackEncoder = audioEncoder.ShortName;
+            audio.FallbackEncoder = job.AudioFallbackEncoder?.ShortName;
 
             audio.AudioList = new List<HandBrake.Interop.Interop.Json.Encode.AudioTrack>();
             foreach (AudioTrack item in job.AudioTracks)
             {
-                HBAudioEncoder encoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(item.Encoder));
-                Validate.NotNull(encoder, "Unrecognized audio encoder:" + item.Encoder);
-
-                if (item.IsPassthru && (item.ScannedTrack.Codec & encoder.Id) == 0)
+                if (item.IsPassthru && (item.ScannedTrack.Codec & item.Encoder.Id) == 0)
                 {
                     // We have an unsupported passthru. Rather than let libhb drop the track, switch it to the fallback.
-                    encoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(job.AllowedPassthruOptions.AudioEncoderFallback));
+                    item.Encoder = job.AudioFallbackEncoder;
                 }
 
                 HBMixdown mixdown = HandBrakeEncoderHelpers.GetMixdown(item.MixDown);
@@ -368,7 +309,7 @@ namespace HandBrakeWPF.Services.Encode.Factories
                 {
                     Track = (item.Track.HasValue ? item.Track.Value : 0) - 1,
                     DRC = item.DRC,
-                    Encoder = encoder.ShortName,
+                    Encoder = item.Encoder?.ShortName,
                     Gain = item.Gain,
                     Mixdown = mixdown != null ? mixdown.Id : -1,
                     NormalizeMixLevel = false,
@@ -395,16 +336,7 @@ namespace HandBrakeWPF.Services.Encode.Factories
             return audio;
         }
 
-        /// <summary>
-        /// The create filter.
-        /// </summary>
-        /// <param name="job">
-        /// The job.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Filters"/>.
-        /// </returns>
-        private static Filters CreateFilters(EncodeTask job)
+        private Filters CreateFilters(EncodeTask job)
         {
             Filters filter = new Filters
             {
@@ -416,11 +348,10 @@ namespace HandBrakeWPF.Services.Encode.Factories
             // Detelecine
             if (job.Detelecine != Detelecine.Off)
             {
-                IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_DETELECINE, null, null, job.CustomDetelecine);
-                string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_DETELECINE, null, null, job.CustomDetelecine);
                 if (!string.IsNullOrEmpty(unparsedJson))
                 {
-                    JToken settings = JObject.Parse(unparsedJson);
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
 
                     Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_DETELECINE, Settings = settings };
                     filter.FilterList.Add(filterItem);
@@ -430,13 +361,12 @@ namespace HandBrakeWPF.Services.Encode.Factories
             // Deinterlace
             if (job.DeinterlaceFilter == DeinterlaceFilter.Yadif)
             {
-                IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_DEINTERLACE, job.DeinterlacePreset?.ShortName,  null, job.CustomDeinterlaceSettings);
-                string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_YADIF, job.DeinterlacePreset?.ShortName, null, job.CustomDeinterlaceSettings);
                 if (!string.IsNullOrEmpty(unparsedJson))
                 {
-                    JToken root = JObject.Parse(unparsedJson);
+                    JsonDocument root = JsonDocument.Parse(unparsedJson);
 
-                    Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_DEINTERLACE, Settings = root };
+                    Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_YADIF, Settings = root };
                     filter.FilterList.Add(filterItem);
                 }
             }
@@ -444,26 +374,37 @@ namespace HandBrakeWPF.Services.Encode.Factories
             // Decomb
             if (job.DeinterlaceFilter == DeinterlaceFilter.Decomb)
             {
-                IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_DECOMB, job.DeinterlacePreset?.ShortName, null, job.CustomDeinterlaceSettings);
-                string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_DECOMB, job.DeinterlacePreset?.ShortName, null, job.CustomDeinterlaceSettings);
                 if (!string.IsNullOrEmpty(unparsedJson))
                 {
-                    JToken settings = JObject.Parse(unparsedJson);
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
 
                     Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_DECOMB, Settings = settings };
                     filter.FilterList.Add(filterItem);
                 }
             }
 
-            if (job.DeinterlaceFilter == DeinterlaceFilter.Decomb || job.DeinterlaceFilter == DeinterlaceFilter.Yadif)
+            // Bwdif
+            if (job.DeinterlaceFilter == DeinterlaceFilter.Bwdif)
+            {
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_BWDIF, job.DeinterlacePreset?.ShortName, null, job.CustomDeinterlaceSettings);
+                if (!string.IsNullOrEmpty(unparsedJson))
+                {
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
+
+                    Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_BWDIF, Settings = settings };
+                    filter.FilterList.Add(filterItem);
+                }
+            }
+
+            if (job.DeinterlaceFilter == DeinterlaceFilter.Decomb || job.DeinterlaceFilter == DeinterlaceFilter.Yadif || job.DeinterlaceFilter == DeinterlaceFilter.Bwdif)
             {
                 if (job.CombDetect != CombDetect.Off)
                 {
-                    IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_COMB_DETECT, EnumHelper<CombDetect>.GetShortName(job.CombDetect), null, job.CustomCombDetect);
-                    string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                    string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_COMB_DETECT, EnumHelper<CombDetect>.GetShortName(job.CombDetect), null, job.CustomCombDetect);
                     if (!string.IsNullOrEmpty(unparsedJson))
                     {
-                        JToken settings = JObject.Parse(unparsedJson);
+                        JsonDocument settings = JsonDocument.Parse(unparsedJson);
 
                         Filter filterItem = new Filter
                                                 {
@@ -482,12 +423,11 @@ namespace HandBrakeWPF.Services.Encode.Factories
                     ? hb_filter_ids.HB_FILTER_HQDN3D
                     : hb_filter_ids.HB_FILTER_NLMEANS;
 
-                IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)id, job.DenoisePreset.ToString().ToLower().Replace(" ", string.Empty), job.DenoiseTune.ToString().ToLower().Replace(" ", string.Empty), job.CustomDenoise);
-                string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)id, job.DenoisePreset?.ShortName, job.DenoiseTune?.ShortName, job.CustomDenoise);
 
                 if (!string.IsNullOrEmpty(unparsedJson))
                 {
-                    JToken settings = JObject.Parse(unparsedJson);
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
 
                     Filter filterItem = new Filter { ID = (int)id, Settings = settings };
                     filter.FilterList.Add(filterItem);
@@ -501,12 +441,11 @@ namespace HandBrakeWPF.Services.Encode.Factories
                     ? hb_filter_ids.HB_FILTER_LAPSHARP
                     : hb_filter_ids.HB_FILTER_UNSHARP;
 
-                IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)id, job.SharpenPreset.Key, job.SharpenTune.Key, job.SharpenCustom);
-                string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)id, job.SharpenPreset.Key, job.SharpenTune.Key, job.SharpenCustom);
 
                 if (!string.IsNullOrEmpty(unparsedJson))
                 {
-                    JToken settings = JObject.Parse(unparsedJson);
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
 
                     Filter filterItem = new Filter { ID = (int)id, Settings = settings };
                     filter.FilterList.Add(filterItem);
@@ -516,11 +455,10 @@ namespace HandBrakeWPF.Services.Encode.Factories
             // Deblock
             if (job.DeblockPreset != null && job.DeblockPreset.Key != "off")
             {
-                IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_DEBLOCK, job.DeblockPreset.Key, job.DeblockTune.Key, job.CustomDeblock);
-                string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_DEBLOCK, job.DeblockPreset.Key, job.DeblockTune.Key, job.CustomDeblock);
                 if (!string.IsNullOrEmpty(unparsedJson))
                 {
-                    JToken settings = JObject.Parse(unparsedJson);
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
 
                     Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_DEBLOCK, Settings = settings };
                     filter.FilterList.Add(filterItem);
@@ -529,11 +467,10 @@ namespace HandBrakeWPF.Services.Encode.Factories
 
             // CropScale Filter
             string cropSettings = string.Format("width={0}:height={1}:crop-top={2}:crop-bottom={3}:crop-left={4}:crop-right={5}", job.Width, job.Height, job.Cropping.Top, job.Cropping.Bottom, job.Cropping.Left, job.Cropping.Right);
-            IntPtr cropSettingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_CROP_SCALE, null, null, cropSettings);
-            string unparsedCropSettingsJson = Marshal.PtrToStringAnsi(cropSettingsPtr);
+            string unparsedCropSettingsJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_CROP_SCALE, null, null, cropSettings);
             if (!string.IsNullOrEmpty(unparsedCropSettingsJson))
             {
-                JToken cropSettingsJson = JObject.Parse(unparsedCropSettingsJson);
+                JsonDocument cropSettingsJson = JsonDocument.Parse(unparsedCropSettingsJson);
 
                 Filter cropScale = new Filter
                                        {
@@ -543,6 +480,60 @@ namespace HandBrakeWPF.Services.Encode.Factories
                 filter.FilterList.Add(cropScale);
             }
 
+            // Padding Filter
+            if (job.Padding.Enabled)
+            {
+                // Calculate the new Width / Height
+                int? width = job.Width;
+                int? height = job.Height;
+                if (job.Padding.Enabled)
+                {
+                    width = width + job.Padding.W;
+                    height = height + job.Padding.H;
+                }
+
+                // Setup the filter.
+                string padSettings = string.Format("width={0}:height={1}:color={2}:x={3}:y={4}", width, height, job.Padding.Color, job.Padding.X, job.Padding.Y);
+                string unparsedPadSettingsJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_PAD, null, null, padSettings);
+                if (!string.IsNullOrEmpty(unparsedPadSettingsJson))
+                {
+                    JsonDocument PadSettingsJson = JsonDocument.Parse(unparsedPadSettingsJson);
+
+                    Filter padding = new Filter
+                                       {
+                                           ID = (int)hb_filter_ids.HB_FILTER_PAD,
+                                           Settings = PadSettingsJson
+                    };
+                    filter.FilterList.Add(padding);
+                }
+            }
+
+            // Colourspace
+            if (job.Colourspace != null && job.Colourspace.Key != "off")
+            {
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_COLORSPACE, job.Colourspace.Key, null, job.CustomColourspace);
+                if (!string.IsNullOrEmpty(unparsedJson))
+                {
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
+
+                    Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_COLORSPACE, Settings = settings };
+                    filter.FilterList.Add(filterItem);
+                }
+            }
+
+            if (job.ChromaSmooth != null && job.ChromaSmooth.Key != "off")
+            {
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_CHROMA_SMOOTH, job.ChromaSmooth.Key, job.ChromaSmoothTune?.Key, job.CustomChromaSmooth);
+                if (!string.IsNullOrEmpty(unparsedJson))
+                {
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
+
+                    Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_CHROMA_SMOOTH, Settings = settings };
+                    filter.FilterList.Add(filterItem);
+                }
+            }
+
+
             // Grayscale
             if (job.Grayscale)
             {
@@ -554,11 +545,10 @@ namespace HandBrakeWPF.Services.Encode.Factories
             if (job.Rotation != 0 || job.FlipVideo)
             {
                 string rotateSettings = string.Format("angle={0}:hflip={1}", job.Rotation, job.FlipVideo ? "1" : "0");
-                IntPtr settingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_ROTATE, null, null, rotateSettings);
-                string unparsedJson = Marshal.PtrToStringAnsi(settingsPtr);
+                string unparsedJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_ROTATE, null, null, rotateSettings);
                 if (!string.IsNullOrEmpty(unparsedJson))
                 {
-                    JToken settings = JObject.Parse(unparsedJson);
+                    JsonDocument settings = JsonDocument.Parse(unparsedJson);
 
                     Filter filterItem = new Filter { ID = (int)hb_filter_ids.HB_FILTER_ROTATE, Settings = settings };
                     filter.FilterList.Add(filterItem);
@@ -570,8 +560,7 @@ namespace HandBrakeWPF.Services.Encode.Factories
             int? num = null, den = null;
             if (job.Framerate != null)
             {
-                IntPtr frameratePrt = Marshal.StringToHGlobalAnsi(job.Framerate.Value.ToString(CultureInfo.InvariantCulture));
-                int vrate = hbFunctions.hb_video_framerate_get_from_name(frameratePrt);
+                int vrate = HandBrakeUnitConversionHelpers.GetFramerateFromName(job.Framerate.Value.ToString(CultureInfo.InvariantCulture));
 
                 if (vrate > 0)
                 {
@@ -581,11 +570,10 @@ namespace HandBrakeWPF.Services.Encode.Factories
             }
 
             string framerateString = num.HasValue ? string.Format("mode={0}:rate={1}/{2}", fm, num, den) : string.Format("mode={0}", fm); // filter_cfr, filter_vrate.num, filter_vrate.den
-            IntPtr framerateSettingsPtr = hbFunctions.hb_generate_filter_settings_json((int)hb_filter_ids.HB_FILTER_VFR, null, null, framerateString);
-            string unparsedFramerateJson = Marshal.PtrToStringAnsi(framerateSettingsPtr);
+            string unparsedFramerateJson = HandBrakeFilterHelpers.GenerateFilterSettingJson((int)hb_filter_ids.HB_FILTER_VFR, null, null, framerateString);
             if (!string.IsNullOrEmpty(unparsedFramerateJson))
             {
-                JToken framerateSettings = JObject.Parse(unparsedFramerateJson);
+                JsonDocument framerateSettings = JsonDocument.Parse(unparsedFramerateJson);
 
                 Filter framerateShaper = new Filter
                                              {
@@ -598,34 +586,27 @@ namespace HandBrakeWPF.Services.Encode.Factories
             return filter;
         }
 
-        /// <summary>
-        /// The create meta data.
-        /// </summary>
-        /// <param name="job">
-        /// The job.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Metadata"/>.
-        /// </returns>
-        private static Metadata CreateMetadata(EncodeTask job)
+        private Metadata CreateMetadata(EncodeTask job)
         {
-            Metadata metaData = new Metadata();
-
-            if (job.MetaData != null)
+            if (job.MetaData != null && job.MetaData.PassthruMetadataEnabled)
             {
-                metaData.Artist = job.MetaData.Artist;
-                metaData.Album = job.MetaData.Album;
-                metaData.AlbumArtist = job.MetaData.AlbumArtist;
-                metaData.Comment = job.MetaData.Comment;
-                metaData.Composer = job.MetaData.Composer;
-                metaData.Description = job.MetaData.Description;
-                metaData.Genre = job.MetaData.Genre;
-                metaData.LongDescription = job.MetaData.LongDescription;
-                metaData.Name = job.MetaData.Name;
-                metaData.ReleaseDate = job.MetaData.ReleaseDate;
+                Metadata metaData = new Metadata
+                                    {
+                                        Artist = job.MetaData.Artist,
+                                        Album = job.MetaData.Album,
+                                        AlbumArtist = job.MetaData.AlbumArtist,
+                                        Comment = job.MetaData.Comment,
+                                        Composer = job.MetaData.Composer,
+                                        Description = job.MetaData.Description,
+                                        Genre = job.MetaData.Genre,
+                                        LongDescription = job.MetaData.LongDescription,
+                                        Name = job.MetaData.Name,
+                                        ReleaseDate = job.MetaData.ReleaseDate
+                                    };
+                return metaData;
             }
 
-            return metaData;
+            return new Metadata(); // Empty Metadata will not pass through to the destination.  
         }
     }
 }
