@@ -14,9 +14,10 @@ namespace HandBrakeWPF.Services.Presets.Factories
     using System.Globalization;
     using System.Linq;
 
+    using HandBrake.App.Core.Utilities;
     using HandBrake.Interop.Interop;
     using HandBrake.Interop.Interop.HbLib;
-    using HandBrake.Interop.Interop.Interfaces.Model;
+    using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
     using HandBrake.Interop.Interop.Interfaces.Model.Filters;
     using HandBrake.Interop.Interop.Interfaces.Model.Picture;
     using HandBrake.Interop.Interop.Interfaces.Model.Presets;
@@ -29,16 +30,11 @@ namespace HandBrakeWPF.Services.Presets.Factories
     using HandBrakeWPF.Model.Video;
     using HandBrakeWPF.Services.Encode.Model.Models;
     using HandBrakeWPF.Services.Presets.Model;
-    using HandBrakeWPF.Utilities;
 
-    using AudioEncoder = Encode.Model.Models.AudioEncoder;
     using AudioTrack = Encode.Model.Models.AudioTrack;
-    using DenoisePreset = Encode.Model.Models.DenoisePreset;
-    using DenoiseTune = Encode.Model.Models.DenoiseTune;
     using EncodeTask = Encode.Model.EncodeTask;
     using FramerateMode = Encode.Model.Models.FramerateMode;
     using OutputFormat = Encode.Model.Models.OutputFormat;
-    using VideoEncoder = HandBrakeWPF.Model.Video.VideoEncoder;
     using VideoEncodeRateType = HandBrakeWPF.Model.Video.VideoEncodeRateType;
     using VideoLevel = Encode.Model.Models.Video.VideoLevel;
     using VideoPreset = Encode.Model.Models.Video.VideoPreset;
@@ -68,12 +64,11 @@ namespace HandBrakeWPF.Services.Presets.Factories
             /* Picture Settings */
             preset.Task.MaxWidth = importedPreset.PictureWidth.HasValue && importedPreset.PictureWidth.Value > 0 ? importedPreset.PictureWidth.Value : (int?)null;
             preset.Task.MaxHeight = importedPreset.PictureHeight.HasValue && importedPreset.PictureHeight.Value > 0 ? importedPreset.PictureHeight.Value : (int?)null;
-            preset.Task.Cropping = new Cropping(importedPreset.PictureTopCrop, importedPreset.PictureBottomCrop, importedPreset.PictureLeftCrop, importedPreset.PictureRightCrop);
-            preset.Task.HasCropping = !importedPreset.PictureAutoCrop;
+
+            preset.Task.Cropping = new Cropping(importedPreset.PictureTopCrop, importedPreset.PictureBottomCrop, importedPreset.PictureLeftCrop, importedPreset.PictureRightCrop, importedPreset.PictureCropMode);
             preset.Task.KeepDisplayAspect = importedPreset.PictureKeepRatio;
             preset.Task.AllowUpscaling = importedPreset.PictureAllowUpscaling;
             preset.Task.OptimalSize = importedPreset.PictureUseMaximumSize;
-
             preset.Task.Padding = new PaddingFilter();
             preset.Task.Padding.Set(importedPreset.PicturePadTop, importedPreset.PicturePadBottom, importedPreset.PicturePadLeft, importedPreset.PicturePadRight, importedPreset.PicturePadColor, importedPreset.PicturePadMode);
             
@@ -82,6 +77,8 @@ namespace HandBrakeWPF.Services.Presets.Factories
                 case "custom":
                     preset.Task.Anamorphic = Anamorphic.Custom;
                     preset.Task.DisplayWidth = importedPreset.PictureDARWidth;
+                    preset.Task.PixelAspectX = importedPreset.PicturePARWidth == 0 ? 1 : importedPreset.PicturePARWidth;
+                    preset.Task.PixelAspectY = importedPreset.PicturePARHeight == 0 ? 1 : importedPreset.PicturePARHeight;
                     break;
                 case "auto":
                 case "loose":
@@ -173,6 +170,9 @@ namespace HandBrakeWPF.Services.Presets.Factories
                 case "yadif":
                     preset.Task.DeinterlaceFilter = DeinterlaceFilter.Yadif;
                     break;
+                case "bwdif":
+                    preset.Task.DeinterlaceFilter = DeinterlaceFilter.Bwdif;
+                    break;
                 default:
                     preset.Task.DeinterlaceFilter = DeinterlaceFilter.Off;
                     break;
@@ -188,13 +188,21 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             if (preset.Task.DeinterlaceFilter == DeinterlaceFilter.Yadif)
             {
-                List<HBPresetTune> filterPresets = HandBrakeFilterHelpers.GetFilterPresets((int)hb_filter_ids.HB_FILTER_DEINTERLACE);
+                List<HBPresetTune> filterPresets = HandBrakeFilterHelpers.GetFilterPresets((int)hb_filter_ids.HB_FILTER_YADIF);
                 HBPresetTune presetTune = filterPresets.FirstOrDefault(f => f.ShortName == importedPreset.PictureDeinterlacePreset);
                 preset.Task.DeinterlacePreset = presetTune ?? new HBPresetTune("Default", "default");
                 preset.Task.CustomDeinterlaceSettings = importedPreset.PictureDeinterlaceCustom;
             }
 
-            if (preset.Task.DeinterlaceFilter == DeinterlaceFilter.Yadif || preset.Task.DeinterlaceFilter == DeinterlaceFilter.Decomb)
+            if (preset.Task.DeinterlaceFilter == DeinterlaceFilter.Bwdif)
+            {
+                List<HBPresetTune> filterPresets = HandBrakeFilterHelpers.GetFilterPresets((int)hb_filter_ids.HB_FILTER_BWDIF);
+                HBPresetTune presetTune = filterPresets.FirstOrDefault(f => f.ShortName == importedPreset.PictureDeinterlacePreset);
+                preset.Task.DeinterlacePreset = presetTune ?? new HBPresetTune("Default", "default");
+                preset.Task.CustomDeinterlaceSettings = importedPreset.PictureDeinterlaceCustom;
+            }
+
+            if (preset.Task.DeinterlaceFilter != DeinterlaceFilter.Off)
             {
                 switch (importedPreset.PictureCombDetectPreset)
                 {
@@ -236,12 +244,15 @@ namespace HandBrakeWPF.Services.Presets.Factories
                     break;
             }
 
+            int denoiseFilterId = 0;
             switch (importedPreset.PictureDenoiseFilter)
             {
                 case "nlmeans":
+                    denoiseFilterId = (int)hb_filter_ids.HB_FILTER_NLMEANS;
                     preset.Task.Denoise = Denoise.NLMeans;
                     break;
                 case "hqdn3d":
+                    denoiseFilterId = (int)hb_filter_ids.HB_FILTER_HQDN3D;
                     preset.Task.Denoise = Denoise.hqdn3d;
                     break;
                 default:
@@ -249,54 +260,9 @@ namespace HandBrakeWPF.Services.Presets.Factories
                     break;
             }
 
-            switch (importedPreset.PictureDenoisePreset)
-            {
-                case "custom":
-                    preset.Task.DenoisePreset = DenoisePreset.Custom;
-                    break;
-                case "light":
-                    preset.Task.DenoisePreset = DenoisePreset.Light;
-                    break;
-                case "medium":
-                    preset.Task.DenoisePreset = DenoisePreset.Medium;
-                    break;
-                case "strong":
-                    preset.Task.DenoisePreset = DenoisePreset.Strong;
-                    break;
-                case "ultralight":
-                    preset.Task.DenoisePreset = DenoisePreset.Ultralight;
-                    break;
-                case "weak":
-                    preset.Task.DenoisePreset = DenoisePreset.Weak;
-                    break;
-            }
-
-            switch (importedPreset.PictureDenoiseTune)
-            {
-                case "animation":
-                    preset.Task.DenoiseTune = DenoiseTune.Animation;
-                    break;
-                case "film":
-                    preset.Task.DenoiseTune = DenoiseTune.Film;
-                    break;
-                case "grain":
-                    preset.Task.DenoiseTune = DenoiseTune.Grain;
-                    break;
-                case "highmotion":
-                    preset.Task.DenoiseTune = DenoiseTune.HighMotion;
-                    break;
-                case "tape":
-                    preset.Task.DenoiseTune = DenoiseTune.Tape;
-                    break;
-                case "sprite":
-                    preset.Task.DenoiseTune = DenoiseTune.Sprite;
-                    break;
-
-                default:
-                    preset.Task.DenoiseTune = DenoiseTune.None;
-                    break;
-            }
-
+            preset.Task.DenoisePreset = HandBrakeFilterHelpers.GetPreset(denoiseFilterId, importedPreset.PictureDenoisePreset);
+            preset.Task.DenoiseTune = HandBrakeFilterHelpers.GetTune(denoiseFilterId, importedPreset.PictureDenoiseTune);
+            
             // Rotation and Flip
             if (!string.IsNullOrEmpty(importedPreset.PictureRotate))
             {
@@ -313,7 +279,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
             }
 
             /* Video Settings */
-            preset.Task.VideoEncoder = EnumHelper<VideoEncoder>.GetValue(importedPreset.VideoEncoder);
+            preset.Task.VideoEncoder = HandBrakeEncoderHelpers.VideoEncoders.FirstOrDefault(s => s.ShortName == importedPreset.VideoEncoder);
             preset.Task.VideoBitrate = importedPreset.VideoAvgBitrate;
             preset.Task.TwoPass = importedPreset.VideoTwoPass;
             preset.Task.TurboFirstPass = importedPreset.VideoTurboTwoPass;
@@ -362,7 +328,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             /* Audio Settings */
             preset.AudioTrackBehaviours = new AudioBehaviours();
-            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioEncoderFallback = EnumHelper<AudioEncoder>.GetValue(importedPreset.AudioEncoderFallback);
+            preset.AudioTrackBehaviours.AudioFallbackEncoder = HandBrakeEncoderHelpers.GetAudioEncoder(importedPreset.AudioEncoderFallback);
             preset.AudioTrackBehaviours.SelectedBehaviour = importedPreset.AudioTrackSelectionBehavior == "all"
                                                                      ? AudioBehaviourModes.AllMatching
                                                                      : AudioBehaviourModes.FirstMatch;
@@ -371,40 +337,10 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             if (importedPreset.AudioCopyMask != null)
             {
-                preset.AudioTrackBehaviours.AllowedPassthruOptions.SetFalse();
+                preset.AudioTrackBehaviours.AllowedPassthruOptions.Clear();
                 foreach (var item in importedPreset.AudioCopyMask)
                 {
-                    AudioEncoder encoder = EnumHelper<AudioEncoder>.GetValue(item);
-                    switch (encoder)
-                    {
-                        case AudioEncoder.AacPassthru:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowAACPass = true;
-                            break;
-                        case AudioEncoder.Ac3Passthrough:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowAC3Pass = true;
-                            break;
-                        case AudioEncoder.EAc3Passthrough:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowEAC3Pass = true;
-                            break;
-                        case AudioEncoder.DtsHDPassthrough:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowDTSHDPass = true;
-                            break;
-                        case AudioEncoder.DtsPassthrough:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowDTSPass = true;
-                            break;
-                        case AudioEncoder.FlacPassthru:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowFlacPass = true;
-                            break;
-                        case AudioEncoder.Mp2Passthru:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowMP2Pass = true;
-                            break;
-                        case AudioEncoder.Mp3Passthru:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowMP3Pass = true;
-                            break;
-                        case AudioEncoder.TrueHDPassthrough:
-                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowTrueHDPass = true;
-                            break;
-                    }
+                    preset.AudioTrackBehaviours.AllowedPassthruOptions.Add(HandBrakeEncoderHelpers.GetAudioEncoder(item));
                 }
             }
 
@@ -423,16 +359,16 @@ namespace HandBrakeWPF.Services.Presets.Factories
             {
                 foreach (var audioTrack in importedPreset.AudioList)
                 {
-                    AudioBehaviourTrack track = new AudioBehaviourTrack(EnumHelper<AudioEncoder>.GetValue(importedPreset.AudioEncoderFallback));
+                    AudioBehaviourTrack track = new AudioBehaviourTrack(HandBrakeEncoderHelpers.GetAudioEncoder(importedPreset.AudioEncoderFallback));
                     
                     // track.CompressionLevel = audioTrack.AudioCompressionLevel;
                     // track.AudioDitherMethod = audioTrack.AudioDitherMethod;
                     if (audioTrack.AudioEncoder == "ca_aac")
                     {
-                        audioTrack.AudioEncoder = "av_aac"; // No Core Audio support on windows.
+                        audioTrack.AudioEncoder = HBAudioEncoder.AvAac; // No Core Audio support on windows.
                     }
 
-                    track.Encoder = EnumHelper<AudioEncoder>.GetValue(audioTrack.AudioEncoder);
+                    track.Encoder = HandBrakeEncoderHelpers.GetAudioEncoder(audioTrack.AudioEncoder);
                     track.MixDown = HandBrakeEncoderHelpers.GetMixdown(audioTrack.AudioMixdown);
                     track.Bitrate = audioTrack.AudioBitrate;
 
@@ -481,7 +417,6 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             /* Not Supported Yet */
             // public int VideoColorMatrixCode { get; set; }
-            // public string VideoScaler { get; set; }
             // public bool VideoQSVDecode { get; set; }
             // public int VideoQSVAsyncDepth { get; set; }
             // public bool SubtitleAddForeignAudioSubtitle { get; set; }
@@ -499,22 +434,22 @@ namespace HandBrakeWPF.Services.Presets.Factories
             return preset;
         }
 
-        public static PresetTransportContainer ExportPreset(Preset export, HBConfiguration config)
+        public static PresetTransportContainer ExportPreset(Preset export)
         {
             PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
             PresetTransportContainer container = new PresetTransportContainer(presetVersion.Major, presetVersion.Minor, presetVersion.Micro);
 
-            container.PresetList = new List<object> { CreateHbPreset(export, config) };
+            container.PresetList = new List<object> { CreateHbPreset(export) };
 
             return container;
         }
 
-        public static PresetTransportContainer ExportPresets(IEnumerable<Preset> exportList, HBConfiguration config)
+        public static PresetTransportContainer ExportPresets(IEnumerable<Preset> exportList)
         {
             PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
             PresetTransportContainer container = new PresetTransportContainer(presetVersion.Major, presetVersion.Minor, presetVersion.Micro);
 
-            List<HBPreset> presets = exportList.Select(item => CreateHbPreset(item, config)).ToList();
+            List<HBPreset> presets = exportList.Select(item => CreateHbPreset(item)).ToList();
 
             container.PresetList = new List<object>();
             container.PresetList.AddRange(presets);
@@ -522,7 +457,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
             return container;
         }
 
-        public static PresetTransportContainer ExportPresetCategories(IList<PresetDisplayCategory> categories, HBConfiguration config)
+        public static PresetTransportContainer ExportPresetCategories(IList<PresetDisplayCategory> categories)
         {
             PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
             PresetTransportContainer container = new PresetTransportContainer(presetVersion.Major, presetVersion.Minor, presetVersion.Micro);
@@ -530,7 +465,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
             List<object> presets = new List<object>();
             foreach (var category in categories)
             {
-                presets.Add(CreatePresetCategory(category, config));
+                presets.Add(CreatePresetCategory(category));
             }
 
             container.PresetList = presets;
@@ -538,7 +473,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
             return container;
         }
 
-        public static HBPresetCategory CreatePresetCategory(PresetDisplayCategory category, HBConfiguration config)
+        public static HBPresetCategory CreatePresetCategory(PresetDisplayCategory category)
         {
             HBPresetCategory preset = new HBPresetCategory();
             preset.Folder = true;
@@ -548,13 +483,13 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             foreach (Preset singlePreset in category.Presets)
             {
-                preset.ChildrenArray.Add(CreateHbPreset(singlePreset, config));
+                preset.ChildrenArray.Add(CreateHbPreset(singlePreset));
             }
 
             return preset;
         }
 
-        public static HBPreset CreateHbPreset(Preset export, HBConfiguration config)
+        public static HBPreset CreateHbPreset(Preset export)
         {
             HBPreset preset = new HBPreset();
 
@@ -565,8 +500,8 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.Default = export.IsDefault;
 
             // Audio
-            preset.AudioCopyMask = export.AudioTrackBehaviours.AllowedPassthruOptions.AllowedPassthruOptions.Select(EnumHelper<AudioEncoder>.GetShortName).ToList();
-            preset.AudioEncoderFallback = EnumHelper<AudioEncoder>.GetShortName(export.AudioTrackBehaviours.AllowedPassthruOptions.AudioEncoderFallback);
+            preset.AudioCopyMask = export.AudioTrackBehaviours.AllowedPassthruOptions.Select(s => s.ShortName).ToList();
+            preset.AudioEncoderFallback = export.AudioTrackBehaviours.AudioFallbackEncoder.ShortName;
             preset.AudioLanguageList = LanguageUtilities.GetLanguageCodes(export.AudioTrackBehaviours.SelectedLanguages);
             preset.AudioTrackSelectionBehavior = EnumHelper<AudioBehaviourModes>.GetShortName(export.AudioTrackBehaviours.SelectedBehaviour);
             preset.AudioSecondaryEncoderMode = export.AudioTrackBehaviours.SelectedTrackDefaultBehaviour == AudioTrackDefaultsMode.FirstTrack; // 1 = First Track, 0 = All
@@ -577,8 +512,8 @@ namespace HandBrakeWPF.Services.Presets.Factories
                 {
                     AudioBitrate = item.Bitrate,
                     AudioCompressionLevel = 0, // TODO
-                    AudioDitherMethod = null,  // TODO
-                    AudioEncoder = EnumHelper<AudioEncoder>.GetShortName(item.Encoder),
+                    AudioDitherMethod = null, // TODO
+                    AudioEncoder = item.Encoder.ShortName,
                     AudioMixdown = item.MixDown != null ? item.MixDown.ShortName : "dpl2",
                     AudioNormalizeMixLevel = false, // TODO
                     AudioSamplerate = item.SampleRate == 0 ? "auto" : item.SampleRate.ToString(CultureInfo.InvariantCulture),  // TODO check formatting.
@@ -615,13 +550,11 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.PictureForceWidth = 0; // TODO
             preset.PictureHeight = export.Task.MaxHeight;
             preset.PictureItuPAR = false; // TODO Not supported Yet
-            preset.PictureKeepRatio = export.Task.KeepDisplayAspect;
-            preset.PictureLeftCrop = export.Task.Cropping.Left;
-            preset.PictureLooseCrop = false; // TODO Not Supported Yet
             preset.PicturePAR = EnumHelper<Anamorphic>.GetShortName(export.Task.Anamorphic);
             preset.PicturePARHeight = export.Task.PixelAspectY;
             preset.PicturePARWidth = export.Task.PixelAspectX;
-            preset.PictureRightCrop = export.Task.Cropping.Right;
+            preset.PictureWidth = export.Task.MaxWidth;
+            preset.PictureDARWidth = export.Task.DisplayWidth.HasValue ? (int)export.Task.DisplayWidth.Value : 0;
 
             preset.PicturePadMode = export.Task.Padding.Mode;
             preset.PicturePadTop = export.Task.Padding.Y;
@@ -630,27 +563,28 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.PicturePadRight = export.Task.Padding.Right;
             preset.PicturePadColor = export.Task.Padding.Color;
             preset.PictureUseMaximumSize = export.Task.OptimalSize;
-            preset.PictureAllowUpscaling = export.Task.AllowUpscaling;
+            preset.PictureAllowUpscaling = export.Task.AllowUpscaling; 
+            preset.PictureKeepRatio = export.Task.KeepDisplayAspect;
 
             if (export.Task.Rotation != 0 || export.Task.FlipVideo)
             {
                 preset.PictureRotate = string.Format("{0}:{1}", export.Task.Rotation, export.Task.FlipVideo ? "1" : "0");
             }
 
+            preset.PictureCropMode = export.Task.Cropping.CropMode;
             preset.PictureTopCrop = export.Task.Cropping.Top;
-            preset.PictureWidth = export.Task.MaxWidth;
-            preset.PictureDARWidth = export.Task.DisplayWidth.HasValue ? (int)export.Task.DisplayWidth.Value : 0;
-            preset.PictureAutoCrop = !export.Task.HasCropping;
             preset.PictureBottomCrop = export.Task.Cropping.Bottom;
+            preset.PictureLeftCrop = export.Task.Cropping.Left;
+            preset.PictureRightCrop = export.Task.Cropping.Right;
 
             // Filters
             preset.PictureDeblockPreset = export.Task.DeblockPreset?.Key;
             preset.PictureDeblockTune = export.Task.DeblockTune?.Key;
             preset.PictureDeblockCustom = export.Task.CustomDeblock;
 
-            preset.PictureDeinterlaceFilter = export.Task.DeinterlaceFilter == DeinterlaceFilter.Decomb
-                ? "decomb"
-                : export.Task.DeinterlaceFilter == DeinterlaceFilter.Yadif ? "yadif" : "off";
+            preset.PictureDeinterlaceFilter = export.Task.DeinterlaceFilter == DeinterlaceFilter.Decomb ? "decomb"
+                : export.Task.DeinterlaceFilter == DeinterlaceFilter.Yadif ? "yadif"
+                : export.Task.DeinterlaceFilter == DeinterlaceFilter.Bwdif ? "bwdif" : "off";
             preset.PictureDeinterlacePreset = export.Task.DeinterlacePreset?.ShortName;
             preset.PictureDeinterlaceCustom = export.Task.CustomDeinterlaceSettings;
 
@@ -659,8 +593,8 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             preset.PictureDenoiseCustom = export.Task.CustomDenoise;
             preset.PictureDenoiseFilter = EnumHelper<Denoise>.GetShortName(export.Task.Denoise);
-            preset.PictureDenoisePreset = EnumHelper<DenoisePreset>.GetShortName(export.Task.DenoisePreset);
-            preset.PictureDenoiseTune = EnumHelper<DenoiseTune>.GetShortName(export.Task.DenoiseTune);
+            preset.PictureDenoisePreset = export.Task.DenoisePreset?.ShortName;
+            preset.PictureDenoiseTune = export.Task.DenoiseTune?.ShortName;
             preset.PictureDetelecine = EnumHelper<Detelecine>.GetShortName(export.Task.Detelecine);
 
             preset.PictureDetelecineCustom = export.Task.CustomDetelecine;
@@ -678,7 +612,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.PictureChromaSmoothCustom = export.Task.CustomChromaSmooth;
             
             // Video
-            preset.VideoEncoder = EnumHelper<VideoEncoder>.GetShortName(export.Task.VideoEncoder);
+            preset.VideoEncoder = export.Task.VideoEncoder?.ShortName;
             preset.VideoFramerate = export.Task.Framerate.HasValue ? export.Task.Framerate.ToString() : null;
             preset.VideoFramerateMode = EnumHelper<FramerateMode>.GetShortName(export.Task.FramerateMode);
             preset.VideoGrayScale = export.Task.Grayscale;
@@ -686,7 +620,6 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.VideoOptionExtra = export.Task.ExtraAdvancedArguments;
             preset.VideoPreset = export.Task.VideoPreset != null ? export.Task.VideoPreset.ShortName : null;
             preset.VideoProfile = export.Task.VideoProfile != null ? export.Task.VideoProfile.ShortName : null;
-            preset.VideoQSVDecode = config.EnableQuickSyncDecoding;
             preset.VideoQualitySlider = export.Task.Quality.HasValue ? export.Task.Quality.Value : 0;
             preset.VideoQualityType = (int)export.Task.VideoEncodeRateType;
             preset.VideoScaler = EnumHelper<VideoScaler>.GetShortName(VideoScaler.Lanczos);
