@@ -15,27 +15,23 @@ namespace HandBrakeWPF.Services.Presets
     using System.ComponentModel;
     using System.IO;
     using System.Linq;
-    using System.Runtime.InteropServices;
     using System.Text.Json;
     using System.Windows;
 
+    using HandBrake.App.Core.Utilities;
     using HandBrake.Interop.Interop;
-    using HandBrake.Interop.Interop.Interfaces.Model;
     using HandBrake.Interop.Interop.Interfaces.Model.Presets;
     using HandBrake.Interop.Interop.Json.Presets;
     using HandBrake.Interop.Utilities;
 
-    using HandBrakeWPF.Factories;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Services.Logging.Interfaces;
     using HandBrakeWPF.Services.Presets.Factories;
     using HandBrakeWPF.Services.Presets.Interfaces;
     using HandBrakeWPF.Services.Presets.Model;
-    using HandBrakeWPF.Utilities;
 
-    using GeneralApplicationException = Exceptions.GeneralApplicationException;
-    using VideoEncoder = HandBrakeWPF.Model.Video.VideoEncoder;
+    using GeneralApplicationException = HandBrake.App.Core.Exceptions.GeneralApplicationException;
 
     public class PresetService : IPresetService
     {
@@ -82,6 +78,22 @@ namespace HandBrakeWPF.Services.Presets
             this.LoadPresets();
         }
 
+        public Preset GetPresetByName(string name)
+        {
+            Preset foundPreset = this.flatPresetList.FirstOrDefault(s => s.Name == name);
+            if (foundPreset != null)
+            {
+                return foundPreset;
+            }
+
+            return null;
+        }
+
+        public Preset GetDefaultPreset()
+        {
+            return new Preset(this.DefaultPreset);
+        }
+
         public bool Add(Preset preset)
         {
             return this.Add(preset, false);
@@ -122,7 +134,7 @@ namespace HandBrakeWPF.Services.Presets
             }
             else
             {
-                this.Update(preset);
+                this.Update(preset.Name, preset);
                 this.OnPresetCollectionChanged();
                 return true;
             }
@@ -205,22 +217,26 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        public void Export(string filename, Preset preset, HBConfiguration configuration)
+        public void Export(string filename, string presetName)
         {
-            PresetTransportContainer container = JsonPresetFactory.ExportPreset(preset, configuration);
+            Preset foundPreset = this.flatPresetList.FirstOrDefault(s => s.Name == presetName);
+            if (foundPreset != null)
+            {
+                PresetTransportContainer container = JsonPresetFactory.ExportPreset(foundPreset);
+                HandBrakePresetService.ExportPreset(filename, container);
+            }
+        }
+
+        public void ExportCategories(string filename, IList<PresetDisplayCategory> categories)
+        {
+            PresetTransportContainer container = JsonPresetFactory.ExportPresetCategories(categories);
             HandBrakePresetService.ExportPreset(filename, container);
         }
 
-        public void ExportCategories(string filename, IList<PresetDisplayCategory> categories, HBConfiguration configuration)
-        {
-            PresetTransportContainer container = JsonPresetFactory.ExportPresetCategories(categories, configuration);
-            HandBrakePresetService.ExportPreset(filename, container);
-        }
-
-        public void Update(Preset update)
+        public void Update(string presetName, Preset update)
         {
             Preset preset;
-            if (this.flatPresetDict.TryGetValue(update.Name, out preset))
+            if (this.flatPresetDict.TryGetValue(presetName, out preset))
             {
                 preset.Task = update.Task;
                 preset.Category = update.Category;
@@ -233,53 +249,26 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        public void Replace(Preset existing, Preset replacement)
+        public void Replace(string presetName, Preset replacement)
         {
-            this.Remove(existing, true, true);
-            this.Add(replacement, false);
-            this.OnPresetCollectionChanged();
+            Preset foundPreset = this.flatPresetList.FirstOrDefault(s => s.Name == presetName);
+            if (foundPreset != null)
+            {
+                this.Remove(foundPreset, true, true);
+                this.Add(replacement, false);
+                this.OnPresetCollectionChanged();
+            }
         }
 
-        public bool Remove(Preset preset)
+        public bool Remove(string presetName)
         {
-            return this.Remove(preset, false, false);
-        }
-
-        public bool Remove(Preset preset, bool overrideDefaultCheck, bool skipCategoryRemoval)
-        {
-            if (preset == null)
+            Preset foundPreset = this.flatPresetList.FirstOrDefault(s => s.Name == presetName);
+            if (foundPreset != null)
             {
-                return false;
+                return this.Remove(foundPreset, false, false);
             }
 
-            if (preset.IsDefault && !overrideDefaultCheck)
-            {
-                return false;
-            }
-            
-            PresetDisplayCategory category = this.presets.FirstOrDefault(p => p.Category == preset.Category) as PresetDisplayCategory;
-            if (category != null)
-            {
-                // Remove the preset, and cleanup the category if it's not got any presets in it.
-                category.Presets.Remove(preset);
-                this.flatPresetList.Remove(preset);
-                this.flatPresetDict.Remove(preset.Name);
-                if (category.Presets.Count == 0 && !skipCategoryRemoval)
-                {
-                    this.presets.Remove(category);
-                }
-            }
-            else
-            {
-                this.presets.Remove(preset);
-                this.flatPresetList.Remove(preset);
-                this.flatPresetDict.Remove(preset.Name);
-            }
-
-            this.SavePresetFiles();
-            this.OnPresetCollectionChanged();
-
-            return true;
+            return false;
         }
 
         public void AddCategory(string categoryName)
@@ -340,18 +329,22 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        public void SetDefault(Preset preset)
+        public void SetDefault(string presetName)
         {
-            // Set IsDefault false for everything.
-            foreach (Preset item in this.flatPresetList)
+            Preset foundPreset = this.flatPresetList.FirstOrDefault(s => s.Name == presetName);
+            if (foundPreset != null)
             {
-                item.IsDefault = false;
+                // Set IsDefault false for everything.
+                foreach (Preset item in this.flatPresetList)
+                {
+                    item.IsDefault = false;
+                }
+
+                // Set the new preset to default.
+                foundPreset.IsDefault = true;
+
+                this.SavePresetFiles();
             }
-
-            // Set the new preset to default.
-            preset.IsDefault = true;
-
-            this.SavePresetFiles();
         }
 
         public Preset GetPreset(string name)
@@ -464,6 +457,34 @@ namespace HandBrakeWPF.Services.Presets
             this.SavePresetFiles();
         }
 
+        public void DeleteBuiltInPresets()
+        {
+            List<Preset> allPresets = this.FlatPresetList;
+            bool foundDefault = false;
+            foreach (Preset preset in allPresets)
+            {
+                if (preset.IsBuildIn)
+                {
+                    if (preset.IsDefault)
+                    {
+                        foundDefault = true;
+                    }
+
+                    this.Remove(preset, true, false); // Remove Default too!
+                }
+            }
+
+            if (foundDefault)
+            {
+                // Try select a new default.
+                Preset preset = this.FlatPresetList.FirstOrDefault();
+                if (preset != null)
+                {
+                    this.SetDefault(preset.Name);
+                }
+            }
+        }
+
         public bool CheckIfPresetExists(string name)
         {
             if (this.flatPresetDict.ContainsKey(name))
@@ -485,39 +506,44 @@ namespace HandBrakeWPF.Services.Presets
             return true;
         }
 
-        public void SetSelected(Preset selectedPreset)
+        public void SetSelected(string presetName)
         {
-            foreach (var item in this.flatPresetList)
+            Preset foundPreset = this.flatPresetList.FirstOrDefault(s => s.Name == presetName);
+            if (foundPreset != null)
             {
-                item.IsSelected = false;
-            }
+                foreach (var item in this.flatPresetList)
+                {
+                    item.IsSelected = false;
+                }
 
-            selectedPreset.IsSelected = true;
+                foundPreset.IsSelected = true;
 
-            IPresetObject category = this.Presets.FirstOrDefault(p => p.Category == selectedPreset.Category);
-            if (category != null)
-            {
-                category.IsExpanded = true;
+                IPresetObject category = this.Presets.FirstOrDefault(p => p.Category == foundPreset.Category);
+                if (category != null)
+                {
+                    category.IsExpanded = true;
+                }
             }
         }
 
-        public void ChangePresetCategory(Preset preset, string categoryName)
+        public void ChangePresetCategory(string presetName, string categoryName)
         {
-            if (string.IsNullOrEmpty(categoryName))
+            Preset foundPreset = this.flatPresetList.FirstOrDefault(s => s.Name == presetName);
+            if (foundPreset != null)
             {
-                return;
-            }
+                if (string.IsNullOrEmpty(categoryName))
+                {
+                    return;
+                }
 
-            if (preset != null)
-            {
-                preset.Category = categoryName;
-            }
+                foundPreset.Category = categoryName;
 
-            this.Save();
-            this.ClearPresetService();
-            this.Load();
-            this.LoadCategoryStates();
-            this.OnPresetCollectionChanged();
+                this.Save();
+                this.ClearPresetService();
+                this.Load();
+                this.LoadCategoryStates();
+                this.OnPresetCollectionChanged();
+            }
         }
 
         public void SaveCategoryStates()
@@ -618,6 +644,7 @@ namespace HandBrakeWPF.Services.Presets
         {
             // First clear the Presets arraylists
             this.presets.Clear();
+            bool forceSave = false;
 
             // Load the presets file.
             try
@@ -634,6 +661,13 @@ namespace HandBrakeWPF.Services.Presets
                 try
                 {
                     container = HandBrakePresetService.GetPresetsFromFile(this.presetFile);
+
+                    PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
+                    if (container.VersionMajor != presetVersion.Major || container.VersionMinor != presetVersion.Minor || container.VersionMicro != presetVersion.Micro)
+                    {
+                        container = HandBrakePresetService.UpgradePresets(this.presetFile);
+                        forceSave = true;
+                    }
                 }
                 catch (Exception exc)
                 {
@@ -674,13 +708,12 @@ namespace HandBrakeWPF.Services.Presets
                 
                 this.ProcessPresetList(container);
 
-                PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
-                if (container.VersionMajor != presetVersion.Major || container.VersionMinor != presetVersion.Minor || container.VersionMicro != presetVersion.Micro)
-                {
-                    this.UpdateBuiltInPresets();
-                }
-
                 CheckAndSetDefault(); // Make a preset default if one we have none.
+
+                if (forceSave)
+                {
+                    this.SavePresetFiles();
+                }
             }
             catch (Exception ex)
             {
@@ -785,11 +818,11 @@ namespace HandBrakeWPF.Services.Presets
             {
                 if (string.IsNullOrEmpty(item.Category))
                 {
-                    uncategorisedPresets.Add(JsonPresetFactory.CreateHbPreset(item, HBConfigurationFactory.Create()));
+                    uncategorisedPresets.Add(JsonPresetFactory.CreateHbPreset(item));
                 }
                 else
                 {
-                    HBPreset preset = JsonPresetFactory.CreateHbPreset(item, HBConfigurationFactory.Create());
+                    HBPreset preset = JsonPresetFactory.CreateHbPreset(item);
                     if (presetCategories.ContainsKey(item.Category))
                     {
                         presetCategories[item.Category].ChildrenArray.Add(preset);
@@ -835,7 +868,7 @@ namespace HandBrakeWPF.Services.Presets
                 MessageBoxResult result = this.errorService.ShowMessageBox(string.Format(Resources.Main_PresetOverwriteWarning, preset.Name), Resources.Overwrite, MessageBoxButton.YesNo, MessageBoxImage.Warning);
                 if (result == MessageBoxResult.Yes)
                 {
-                    this.Update(preset);
+                    this.Update(preset.Name, preset);
                 }
             }
             else
@@ -850,49 +883,26 @@ namespace HandBrakeWPF.Services.Presets
             bool isNvencEnabled = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableNvencEncoder);
             bool isVcnEnabled = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableVceEncoder);
 
-            if (preset.Task.VideoEncoder == VideoEncoder.QuickSync && (!HandBrakeHardwareEncoderHelper.IsQsvAvailable || !isQsvEnabled))
+            if (preset.Task.VideoEncoder == null)
             {
                 return true;
             }
 
-            if (preset.Task.VideoEncoder == VideoEncoder.QuickSyncH265 && (!HandBrakeHardwareEncoderHelper.IsQsvAvailableH265 || !isQsvEnabled))
+            if (preset.Task.VideoEncoder.IsQuickSync && !isQsvEnabled)
             {
                 return true;
             }
 
-            if (preset.Task.VideoEncoder == VideoEncoder.QuickSyncH26510b && (!HandBrakeHardwareEncoderHelper.IsQsvAvailableH265 || !isQsvEnabled))
+            if (preset.Task.VideoEncoder.IsNVEnc && !isNvencEnabled)
             {
                 return true;
             }
 
-            if (preset.Task.VideoEncoder == VideoEncoder.VceH264 && (!HandBrakeHardwareEncoderHelper.IsVceH264Available || !isVcnEnabled))
+            if (preset.Task.VideoEncoder.IsVCN && !isVcnEnabled)
             {
                 return true;
             }
 
-            if (preset.Task.VideoEncoder == VideoEncoder.VceH265 && (!HandBrakeHardwareEncoderHelper.IsVceH265Available || !isVcnEnabled))
-            {
-                return true;
-            }
-
-            if (preset.Task.VideoEncoder == VideoEncoder.NvencH264 && (!HandBrakeHardwareEncoderHelper.IsNVEncH264Available || !isNvencEnabled))
-            {
-                return true;
-            }
-
-            if (preset.Task.VideoEncoder == VideoEncoder.NvencH265 && (!HandBrakeHardwareEncoderHelper.IsNVEncH265Available || !isNvencEnabled))
-            {
-                return true;
-            }
-
-            if (preset.Task.VideoEncoder == VideoEncoder.MFH264 || preset.Task.VideoEncoder == VideoEncoder.MFH265)
-            {
-                if (RuntimeInformation.ProcessArchitecture != Architecture.Arm64)
-                {
-                    return true;
-                }
-            }
-
             return false;
         }
 
@@ -912,7 +922,44 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        protected void ServiceLogMessage(string message)
+        private bool Remove(Preset preset, bool overrideDefaultCheck, bool skipCategoryRemoval)
+        {
+            if (preset == null)
+            {
+                return false;
+            }
+
+            if (preset.IsDefault && !overrideDefaultCheck)
+            {
+                return false;
+            }
+
+            PresetDisplayCategory category = this.presets.FirstOrDefault(p => p.Category == preset.Category) as PresetDisplayCategory;
+            if (category != null)
+            {
+                // Remove the preset, and cleanup the category if it's not got any presets in it.
+                category.Presets.Remove(preset);
+                this.flatPresetList.Remove(preset);
+                this.flatPresetDict.Remove(preset.Name);
+                if (category.Presets.Count == 0 && !skipCategoryRemoval)
+                {
+                    this.presets.Remove(category);
+                }
+            }
+            else
+            {
+                this.presets.Remove(preset);
+                this.flatPresetList.Remove(preset);
+                this.flatPresetDict.Remove(preset.Name);
+            }
+
+            this.SavePresetFiles();
+            this.OnPresetCollectionChanged();
+
+            return true;
+        }
+
+        private void ServiceLogMessage(string message)
         {
             this.log.LogMessage(string.Format("Preset Service: {0}{1}{0}", Environment.NewLine, message));
         }
