@@ -15,15 +15,12 @@ namespace HandBrakeWPF.ViewModels
     using System.Globalization;
     using System.IO;
     using System.Linq;
-    using System.Threading;
-    using System.Threading.Tasks;
     using System.Windows;
     using System.Windows.Media;
 
-    using Caliburn.Micro;
-
+    using HandBrake.App.Core.Utilities;
     using HandBrake.Interop.Interop;
-
+    using HandBrakeWPF.Helpers;
     using HandBrakeWPF.Model;
     using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Model.Video;
@@ -38,7 +35,7 @@ namespace HandBrakeWPF.ViewModels
 
     using Ookii.Dialogs.Wpf;
 
-    using Execute = Caliburn.Micro.Execute;
+    using ILog = HandBrakeWPF.Services.Logging.Interfaces.ILog;
 
     public class OptionsViewModel : ViewModelBase, IOptionsViewModel
     {
@@ -49,6 +46,8 @@ namespace HandBrakeWPF.ViewModels
 
         private readonly INotificationService notificationService;
 
+        private readonly ILog logService;
+
         private string arguments;
         private string autoNameDefaultPath;
         private bool automaticallyNameFiles;
@@ -116,8 +115,18 @@ namespace HandBrakeWPF.ViewModels
         private bool remoteServiceEnabled;
         private bool enableQuickSyncLowPower;
         private int simultaneousEncodes;
+        private bool enableQuickSyncHyperEncode;
 
-        public OptionsViewModel(IUserSettingService userSettingService, IUpdateService updateService, IAboutViewModel aboutViewModel, IErrorService errorService, IPresetService presetService, INotificationService notificationService)
+        private bool enableNvDecSupport;
+
+        public OptionsViewModel(
+            IUserSettingService userSettingService,
+            IUpdateService updateService, 
+            IAboutViewModel aboutViewModel, 
+            IErrorService errorService, 
+            IPresetService presetService, 
+            INotificationService notificationService, 
+            ILog logService)
         {
             this.Title = "Options";
             this.userSettingService = userSettingService;
@@ -125,6 +134,7 @@ namespace HandBrakeWPF.ViewModels
             this.errorService = errorService;
             this.presetService = presetService;
             this.notificationService = notificationService;
+            this.logService = logService;
             this.AboutViewModel = aboutViewModel;
             this.OnLoad();
 
@@ -665,30 +675,39 @@ namespace HandBrakeWPF.ViewModels
             set
             {
                 this.selectedPriority = value;
-                this.NotifyOfPropertyChange();
+                this.NotifyOfPropertyChange(() => this.SelectedPriority);
+                this.SetProcessPriority(value);
+            }
+        }
 
-                // Set the Process Priority
-                switch (value)
-                {
-                    case ProcessPriority.High:
-                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.High;
-                        break;
-                    case ProcessPriority.AboveNormal:
-                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.AboveNormal;
-                        break;
-                    case ProcessPriority.Normal:
-                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Normal;
-                        break;
-                    case ProcessPriority.BelowNormal:
-                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.BelowNormal;
-                        break;
-                    case ProcessPriority.Low:
-                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Idle;
-                        break;
-                    default:
-                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.BelowNormal;
-                        break;
-                }
+        private void SetProcessPriority(ProcessPriority value)
+        {
+            if (this.RemoteServiceEnabled)
+            {
+                return; // We run as "Normal" in Remote mode.
+            }
+
+            // Set the Process Priority
+            switch (value)
+            {
+                case ProcessPriority.High:
+                    Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.High;
+                    break;
+                case ProcessPriority.AboveNormal:
+                    Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.AboveNormal;
+                    break;
+                case ProcessPriority.Normal:
+                    Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Normal;
+                    break;
+                case ProcessPriority.BelowNormal:
+                    Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.BelowNormal;
+                    break;
+                case ProcessPriority.Low:
+                    Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Idle;
+                    break;
+                default:
+                    Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.BelowNormal;
+                    break;
             }
         }
 
@@ -857,12 +876,13 @@ namespace HandBrakeWPF.ViewModels
 
                 this.enableNvencEncoder = value;
                 this.NotifyOfPropertyChange(() => this.EnableNvencEncoder);
+                this.NotifyOfPropertyChange(() => this.IsNvdecAvailable);
             }
         }
 
         public bool EnableQuickSyncDecoding
         {
-            get => this.enableQuickSyncDecoding;
+            get => this.enableQuickSyncDecoding && IsQuickSyncAvailable;
 
             set
             {
@@ -891,18 +911,34 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool EnableQuickSyncHyperEncode
+        {
+            get => this.enableQuickSyncHyperEncode;
+            set
+            {
+                if (value == this.enableQuickSyncHyperEncode)
+                {
+                    return;
+                }
+
+                this.enableQuickSyncHyperEncode = value;
+                this.NotifyOfPropertyChange(() => this.EnableQuickSyncHyperEncode);
+            }
+        }
+
         public VideoScaler SelectedScalingMode { get; set; }
 
         public bool IsQuickSyncAvailable { get; } = HandBrakeHardwareEncoderHelper.IsQsvAvailable;
 
+        public bool IsQuickSyncHyperEncodeAvailable { get; } = HandBrakeHardwareEncoderHelper.IsQsvHyperEncodeAvailable;
+
         public bool IsVceAvailable { get; } = HandBrakeHardwareEncoderHelper.IsVceH264Available;
 
         public bool IsNvencAvailable { get; } = HandBrakeHardwareEncoderHelper.IsNVEncH264Available;
 
-        public bool IsUseQsvDecAvailable
-        {
-            get => this.IsQuickSyncAvailable && this.EnableQuickSyncDecoding;
-        }
+        public bool IsUseQsvDecAvailable => this.IsQuickSyncAvailable && this.EnableQuickSyncDecoding;
+
+        public bool IsNvdecAvailable => HandBrakeHardwareEncoderHelper.IsNVDecAvailable && this.EnableNvencEncoder;
 
         public bool UseQSVDecodeForNonQSVEnc
         {
@@ -924,6 +960,18 @@ namespace HandBrakeWPF.ViewModels
 
         public bool IsHardwareOptionsVisible => !IsSafeMode && !IsHardwareFallbackMode;
 
+        public bool IsAutomaticSafeMode { get; private set; }
+
+        public bool EnableNvDecSupport
+        {
+            get => this.enableNvDecSupport;
+            set
+            {
+                if (value == this.enableNvDecSupport) return;
+                this.enableNvDecSupport = value;
+                this.NotifyOfPropertyChange(() => this.EnableNvDecSupport);
+            }
+        }
 
         /* About HandBrake */
 
@@ -1035,7 +1083,7 @@ namespace HandBrakeWPF.ViewModels
         {
             this.Save();
 
-            IShellViewModel shellViewModel = IoC.Get<IShellViewModel>();
+            IShellViewModel shellViewModel = IoCHelper.Get<IShellViewModel>();
             shellViewModel.DisplayWindow(ShellWindow.MainWindow);
         }
 
@@ -1135,7 +1183,10 @@ namespace HandBrakeWPF.ViewModels
                 var player = new MediaPlayer();
                 player.Open(uri);
                 player.Play();
-                player.MediaFailed += (object sender, ExceptionEventArgs e) => { Debug.WriteLine(e); };
+                player.MediaFailed += (object sender, ExceptionEventArgs e) =>
+                {
+                    this.logService.LogMessage(string.Format("{1} # {0}{1}", e?.ErrorException, Environment.NewLine));
+                };
             }
             else
             {
@@ -1147,6 +1198,19 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public void ResetAutomaticSafeMode()
+        {
+            userSettingService.SetUserSetting(UserSettingConstants.ForceDisableHardwareSupport, false);
+            this.errorService.ShowMessageBox(
+                Resources.OptionsView_ResetSafeModeMessage,
+                Resources.Notice,
+                MessageBoxButton.OK,
+                MessageBoxImage.Information);
+
+            this.IsAutomaticSafeMode = false;
+            this.NotifyOfPropertyChange(() => this.IsAutomaticSafeMode);
+        }
+
         #endregion
 
         public override void OnLoad()
@@ -1250,14 +1314,25 @@ namespace HandBrakeWPF.ViewModels
             this.SelectedScalingMode = this.userSettingService.GetUserSetting<VideoScaler>(UserSettingConstants.ScalingMode);
             this.UseQSVDecodeForNonQSVEnc = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.UseQSVDecodeForNonQSVEnc);
             this.EnableQuickSyncLowPower = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncLowPower);
+            this.EnableQuickSyncHyperEncode = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncHyperEncode);
 
             this.EnableQuickSyncEncoding = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncEncoding);
             this.EnableVceEncoder = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableVceEncoder);
             this.EnableNvencEncoder = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableNvencEncoder);
+            this.EnableNvDecSupport = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableNvDecSupport);
 
             // #############################
-            // CLI
+            // Process
             // #############################
+
+            this.RemoteServiceEnabled = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ProcessIsolationEnabled);
+            this.RemoteServicePort = userSettingService.GetUserSetting<int>(UserSettingConstants.ProcessIsolationPort);
+            this.SimultaneousEncodes = userSettingService.GetUserSetting<int>(UserSettingConstants.SimultaneousEncodes);
+            if (this.SimultaneousEncodes > 8)
+            {
+                this.SimultaneousEncodes = 8;
+            }
+
             this.SelectedPriority = (ProcessPriority)userSettingService.GetUserSetting<int>(UserSettingConstants.ProcessPriorityInt);
 
             this.PreventSleep = userSettingService.GetUserSetting<bool>(UserSettingConstants.PreventSleep);
@@ -1320,15 +1395,10 @@ namespace HandBrakeWPF.ViewModels
             this.LowBatteryLevel = userSettingService.GetUserSetting<int>(UserSettingConstants.LowBatteryLevel);
 
             // #############################
-            // Experimental
+            // Safe Mode
             // #############################
-            this.RemoteServiceEnabled = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ProcessIsolationEnabled);
-            this.RemoteServicePort = userSettingService.GetUserSetting<int>(UserSettingConstants.ProcessIsolationPort);
-            this.SimultaneousEncodes = userSettingService.GetUserSetting<int>(UserSettingConstants.SimultaneousEncodes);
-            if (this.SimultaneousEncodes > 8)
-            {
-                this.SimultaneousEncodes = 8;
-            }
+            this.IsAutomaticSafeMode = userSettingService.GetUserSetting<bool>(UserSettingConstants.ForceDisableHardwareSupport);
+            this.NotifyOfPropertyChange(() => this.IsAutomaticSafeMode);
         }
 
         public void UpdateSettings()
@@ -1386,12 +1456,6 @@ namespace HandBrakeWPF.ViewModels
             this.errorService.ShowMessageBox(Resources.OptionsView_UninstallMessageBoxText, Resources.OptionsView_UninstallMessageBoxHeader, MessageBoxButton.OK, MessageBoxImage.Information);
         }
 
-        protected override Task OnActivateAsync(CancellationToken cancellationToken)
-        {
-            this.OnLoad();
-            return base.OnActivateAsync(cancellationToken);
-        }
-
         private void Save()
         {
             /* General */
@@ -1440,10 +1504,11 @@ namespace HandBrakeWPF.ViewModels
             this.userSettingService.SetUserSetting(UserSettingConstants.EnableQuickSyncDecoding, this.EnableQuickSyncDecoding);
             this.userSettingService.SetUserSetting(UserSettingConstants.ScalingMode, this.SelectedScalingMode);
             this.userSettingService.SetUserSetting(UserSettingConstants.UseQSVDecodeForNonQSVEnc, this.UseQSVDecodeForNonQSVEnc);
-
+            this.userSettingService.SetUserSetting(UserSettingConstants.EnableQuickSyncHyperEncode, this.EnableQuickSyncHyperEncode);
             this.userSettingService.SetUserSetting(UserSettingConstants.EnableQuickSyncEncoding, this.EnableQuickSyncEncoding);
             this.userSettingService.SetUserSetting(UserSettingConstants.EnableVceEncoder, this.EnableVceEncoder);
             this.userSettingService.SetUserSetting(UserSettingConstants.EnableNvencEncoder, this.EnableNvencEncoder);
+            this.userSettingService.SetUserSetting(UserSettingConstants.EnableNvDecSupport, this.EnableNvDecSupport);
             this.userSettingService.SetUserSetting(UserSettingConstants.EnableQuickSyncLowPower, this.EnableQuickSyncLowPower);
 
             /* System and Logging */
@@ -1539,7 +1604,7 @@ namespace HandBrakeWPF.ViewModels
                                 };
 
                     installer.Start();
-                    Execute.OnUIThread(() => Application.Current.Shutdown());
+                    ThreadHelper.OnUIThread(() => Application.Current.Shutdown());
                 }
                 catch (Exception exc)
                 {
