@@ -1,5 +1,5 @@
 ﻿// --------------------------------------------------------------------------------------------------------------------
-// <copyright file="PresetManagerViewModel.cs" company="HandBrake Project (http://handbrake.fr)">
+// <copyright file="PresetManagerViewModel.cs" company="HandBrake Project (https://handbrake.fr)">
 //   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
 // </copyright>
 // <summary>
@@ -9,15 +9,15 @@
 
 namespace HandBrakeWPF.ViewModels
 {
+    using System;
     using System.Collections.Generic;
     using System.ComponentModel;
     using System.Diagnostics;
     using System.Linq;
     using System.Windows;
 
-    using Caliburn.Micro;
+    using HandBrake.App.Core.Utilities;
 
-    using HandBrakeWPF.Factories;
     using HandBrakeWPF.Model.Audio;
     using HandBrakeWPF.Model.Picture;
     using HandBrakeWPF.Model.Subtitles;
@@ -25,25 +25,21 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Services.Presets.Interfaces;
     using HandBrakeWPF.Services.Presets.Model;
-    using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
-    using HandBrakeWPF.Views;
 
     using Microsoft.Win32;
 
-    using Action = System.Action;
-
     public class PresetManagerViewModel : ViewModelBase, IPresetManagerViewModel
     {
         private readonly IPresetService presetService;
         private readonly IErrorService errorService;
         private readonly IWindowManager windowManager;
-        private readonly PresetDisplayCategory addNewCategory = new PresetDisplayCategory(Resources.AddPresetView_AddNewCategory, true, null);
 
         private IPresetObject selectedPresetCategory;
         private Preset selectedPreset;
         private PictureSettingsResLimitModes selectedPictureSettingsResLimitMode;
-        private Action mainWindowCallback;
+        private Action<Preset> mainWindowCallback;
+        private string presetNameKey;
 
         public PresetManagerViewModel(IPresetService presetService, IErrorService errorService, IWindowManager windowManager)
         {
@@ -73,15 +69,13 @@ namespace HandBrakeWPF.ViewModels
 
             set
             {
-                if (this.selectedPreset != null && value != null  && value.Category != this.selectedPreset.Category)
+                if (this.selectedPreset != null && value != null && value.Category != this.selectedPreset.Category)
                 {
-                    this.presetService.ChangePresetCategory(this.selectedPreset, value.Category);
+                    this.presetService.ChangePresetCategory(this.selectedPreset.Name, value.Category);
                 }
             }
         }
 
-        public string SelectedItem { get; set; }
-
         public IPresetObject SelectedPresetCategory
         {
             get => this.selectedPresetCategory;
@@ -92,9 +86,6 @@ namespace HandBrakeWPF.ViewModels
                     this.selectedPresetCategory = value;
                     this.NotifyOfPropertyChange(() => this.SelectedPresetCategory);
 
-                    this.SelectedItem = value?.Category;
-                    this.NotifyOfPropertyChange(() => this.SelectedItem);
-
                     this.selectedPreset = null;
                     this.NotifyOfPropertyChange(() => this.SelectedPreset);
                 }
@@ -114,22 +105,22 @@ namespace HandBrakeWPF.ViewModels
 
                     if (value != null)
                     {
-                        this.SelectedItem = value.Name;
-                        this.NotifyOfPropertyChange(() => this.SelectedItem);
-
-                        this.IsBuildIn = value.IsBuildIn;
-
+                        this.PresetName = value?.Name;
+                        this.presetNameKey = value?.Name;
                         this.CustomWidth = value.Task.MaxWidth;
                         this.CustomHeight = value.Task.MaxHeight;
                         this.SetSelectedPictureSettingsResLimitMode();
                     }
                     else
                     {
+                        this.PresetName = null;
+                        this.presetNameKey = null;
                         this.selectedPresetCategory = null;
                         this.NotifyOfPropertyChange(() => this.SelectedPresetCategory);
                     }
                 }
 
+                this.NotifyOfPropertyChange(() => this.PresetName);
                 this.NotifyOfPropertyChange(() => this.IsBuildIn);
                 this.NotifyOfPropertyChange(() => this.SelectedUserPresetCategory);
                 this.NotifyOfPropertyChange(() => this.IsPresetSelected);
@@ -137,21 +128,15 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        public bool IsBuildIn { get; private set; }
+        public bool IsBuildIn => this.SelectedPreset?.IsBuildIn ?? true;
 
         public bool IsPresetSelected => this.SelectedPreset != null;
 
-        public BindingList<PictureSettingsResLimitModes> ResolutionLimitModes => new BindingList<PictureSettingsResLimitModes>
-                                                                                 {
-                                                                                     PictureSettingsResLimitModes.None,
-                                                                                     PictureSettingsResLimitModes.Size8K,
-                                                                                     PictureSettingsResLimitModes.Size4K,
-                                                                                     PictureSettingsResLimitModes.Size1080p,
-                                                                                     PictureSettingsResLimitModes.Size720p,
-                                                                                     PictureSettingsResLimitModes.Size576p,
-                                                                                     PictureSettingsResLimitModes.Size480p,
-                                                                                     PictureSettingsResLimitModes.Custom,
-                                                                                 };
+        public BindingList<PictureSettingsResLimitModes> ResolutionLimitModes => new BindingList<PictureSettingsResLimitModes>(EnumHelper<PictureSettingsResLimitModes>.GetEnumList().ToList());
+
+        public bool IsPresetNameChanged => this.PresetName != this.presetNameKey;
+
+        public string PresetName { get; set; }
 
         public PictureSettingsResLimitModes SelectedPictureSettingsResLimitMode
         {
@@ -219,7 +204,7 @@ namespace HandBrakeWPF.ViewModels
 
         public bool IsCustomMaxRes { get; private set; }
 
-        public void SetupWindow(Action mainwindowCallback)
+        public void SetupWindow(Action<Preset> mainwindowCallback)
         {
             this.mainWindowCallback = mainwindowCallback;
             this.PresetsCategories = this.presetService.Presets;
@@ -229,6 +214,31 @@ namespace HandBrakeWPF.ViewModels
             this.presetService.PresetCollectionChanged += this.PresetService_PresetCollectionChanged;
         }
 
+        public void RenamePreset()
+        {
+            if (this.SelectedPreset != null)
+            {
+                this.SelectedPreset.Name = this.PresetName;
+
+                this.presetService.Update(this.presetNameKey, this.SelectedPreset);
+
+                this.PresetsCategories = null;
+                this.NotifyOfPropertyChange(() => this.PresetsCategories);
+
+                this.PresetsCategories = this.presetService.Presets;
+                this.NotifyOfPropertyChange(() => this.PresetsCategories);
+
+                this.SelectedPreset = this.presetService.GetPresetByName(this.SelectedPreset.Name);
+
+                this.NotifyOfPropertyChange(() => this.IsPresetNameChanged);
+
+                if (this.mainWindowCallback != null)
+                {
+                    mainWindowCallback(this.selectedPreset);
+                }
+            }
+        }
+
         public void DeletePreset()
         {
             if (this.selectedPreset != null)
@@ -256,9 +266,9 @@ namespace HandBrakeWPF.ViewModels
                     return;
                 }
 
-                this.presetService.Remove(this.selectedPreset);
+                this.presetService.Remove(this.selectedPreset.Name);
                 this.NotifyOfPropertyChange(() => this.PresetsCategories);
-                this.SelectedPreset = this.presetService.DefaultPreset;
+                this.SelectedPreset = this.presetService.GetDefaultPreset();
             }
             else
             {
@@ -270,7 +280,7 @@ namespace HandBrakeWPF.ViewModels
         {
             if (this.selectedPreset != null)
             {
-                this.presetService.SetDefault(this.selectedPreset);
+                this.presetService.SetDefault(this.selectedPreset.Name);
                 this.errorService.ShowMessageBox(string.Format(Resources.Main_NewDefaultPreset, this.selectedPreset.Name), Resources.Main_Presets, MessageBoxButton.OK, MessageBoxImage.Information);
             }
             else
@@ -309,7 +319,7 @@ namespace HandBrakeWPF.ViewModels
 
                 if (!string.IsNullOrEmpty(filename))
                 {
-                    this.presetService.Export(savefiledialog.FileName, this.selectedPreset, HBConfigurationFactory.Create());
+                    this.presetService.Export(savefiledialog.FileName, this.selectedPreset.Name);
                 }
             }
             else
@@ -336,38 +346,17 @@ namespace HandBrakeWPF.ViewModels
             if (!string.IsNullOrEmpty(filename))
             {
                 IList<PresetDisplayCategory> userPresets = this.presetService.GetPresetCategories(true);
-                this.presetService.ExportCategories(savefiledialog.FileName, userPresets, HBConfigurationFactory.Create());
+                this.presetService.ExportCategories(savefiledialog.FileName, userPresets);
             }
         }
 
         public void DeleteBuiltInPresets()
         {
-            List<Preset> allPresets = this.presetService.FlatPresetList;
-            bool foundDefault = false;
-            foreach (Preset preset in allPresets)
+            this.presetService.DeleteBuiltInPresets();
+            if (this.presetService.GetDefaultPreset() != null)
             {
-                if (preset.IsBuildIn)
-                {
-                    if (preset.IsDefault)
-                    {
-                        foundDefault = true;
-                    }
-
-                    this.presetService.Remove(preset);
-                }
+                this.SelectedPreset = this.presetService.GetDefaultPreset();
             }
-
-            if (foundDefault)
-            {
-                Preset preset = this.presetService.FlatPresetList.FirstOrDefault();
-                if (preset != null)
-                {
-                    this.presetService.SetDefault(preset);
-                    this.SelectedPreset = preset;
-                }
-            }
-
-            this.NotifyOfPropertyChange(() => this.PresetsCategories);
         }
 
         public void ResetBuiltInPresets()
@@ -423,7 +412,7 @@ namespace HandBrakeWPF.ViewModels
 
             if (this.mainWindowCallback != null)
             {
-                mainWindowCallback();
+                mainWindowCallback(this.selectedPreset);
             }
         }
 
@@ -431,7 +420,7 @@ namespace HandBrakeWPF.ViewModels
         {
             if (this.SelectedPreset != null)
             {
-                this.presetService.SetDefault(this.SelectedPreset);
+                this.presetService.SetDefault(this.SelectedPreset.Name);
             }
         }
 
@@ -440,17 +429,22 @@ namespace HandBrakeWPF.ViewModels
             Process.Start("explorer.exe", "https://handbrake.fr/docs/en/latest/advanced/custom-presets.html");
         }
 
+        public void SetPresetNameChanged()
+        {
+            this.NotifyOfPropertyChange(() => this.IsPresetNameChanged);
+        }
+
         private void SetDefaultPreset()
         {
             // Preset Selection
-            if (this.presetService.DefaultPreset != null)
+            if (this.presetService.GetDefaultPreset() != null)
             {
                 PresetDisplayCategory category =
                     (PresetDisplayCategory)this.PresetsCategories.FirstOrDefault(
-                        p => p.Category == this.presetService.DefaultPreset.Category);
+                        p => p.Category == this.presetService.GetDefaultPreset().Category);
 
                 this.SelectedPresetCategory = category;
-                this.SelectedPreset = this.presetService.DefaultPreset;
+                this.SelectedPreset = this.presetService.GetDefaultPreset();
             }
         }
 
@@ -494,7 +488,7 @@ namespace HandBrakeWPF.ViewModels
             // Reselect the preset as the object has changed due to the reload that occurred.
             if (!string.IsNullOrEmpty(presetName))
             {
-                this.SelectedPreset = this.presetService.FlatPresetList.FirstOrDefault(s => s.Name == presetName);
+                this.SelectedPreset = this.presetService.GetPresetByName(presetName);
             }
         }
     }
