@@ -13,17 +13,15 @@ namespace HandBrakeWPF.ViewModels
     using System.Collections.Generic;
     using System.Diagnostics;
     using System.IO;
-    using System.Runtime.ExceptionServices;
     using System.Text;
-    using System.Windows.Media;
     using System.Windows.Media.Imaging;
 
+    using HandBrake.App.Core.Utilities;
     using HandBrake.Interop.Interop;
     using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
     using HandBrake.Interop.Interop.Interfaces.Model.Picture;
 
     using HandBrakeWPF.EventArgs;
-    using HandBrakeWPF.Factories;
     using HandBrakeWPF.Helpers;
     using HandBrakeWPF.Model.Filters;
     using HandBrakeWPF.Model.Options;
@@ -34,12 +32,9 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.Services.Presets.Model;
     using HandBrakeWPF.Services.Scan.Interfaces;
     using HandBrakeWPF.Services.Scan.Model;
-    using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModelItems.Filters;
     using HandBrakeWPF.ViewModels.Interfaces;
 
-    using VideoEncoder = HandBrakeWPF.Model.Video.VideoEncoder;
-
     public class SummaryViewModel : ViewModelBase, ISummaryViewModel
     {
         private readonly IScan scanService;
@@ -264,7 +259,7 @@ namespace HandBrakeWPF.ViewModels
                     return false;
                 }
 
-                return this.SelectedOutputFormat == OutputFormat.Mp4 && VideoEncoderHelpers.IsH264(this.task.VideoEncoder);
+                return this.SelectedOutputFormat == OutputFormat.Mp4 && this.task.VideoEncoder != null && this.task.VideoEncoder.IsH264;
             }
         }
 
@@ -496,9 +491,6 @@ namespace HandBrakeWPF.ViewModels
             {
                 switch ((Mp4Behaviour)this.userSettingService.GetUserSetting<int>(UserSettingConstants.UseM4v))
                 {
-                    case Mp4Behaviour.Auto: // Auto
-                        newExtension = MP4Helper.RequiresM4v(this.Task) ? ".m4v" : ".mp4";
-                        break;
                     case Mp4Behaviour.MP4: // MP4
                         newExtension = ".mp4";
                         break;
@@ -516,7 +508,7 @@ namespace HandBrakeWPF.ViewModels
                 this.AlignAVStart = false;
             }
 
-            if (!VideoEncoderHelpers.IsH264(this.task.VideoEncoder))
+            if (this.task.VideoEncoder == null || !this.task.VideoEncoder.IsH264)
             {
                 this.IPod5GSupport = false;
             }
@@ -544,8 +536,8 @@ namespace HandBrakeWPF.ViewModels
 
             // Dimension Section
             this.VideoTrackInfo = this.Task.Framerate == null 
-                                      ? string.Format("{0}, {1} FPS {2}", EnumHelper<VideoEncoder>.GetDisplay(this.Task.VideoEncoder), Resources.SummaryView_SameAsSource, this.Task.FramerateMode) 
-                                      : string.Format("{0}, {1} FPS {2}", EnumHelper<VideoEncoder>.GetDisplay(this.Task.VideoEncoder), this.Task.Framerate, this.Task.FramerateMode);
+                                      ? string.Format("{0}, {1} FPS {2}", this.Task.VideoEncoder?.DisplayName, Resources.SummaryView_SameAsSource, this.Task.FramerateMode) 
+                                      : string.Format("{0}, {1} FPS {2}", this.Task.VideoEncoder?.DisplayName, this.Task.Framerate, this.Task.FramerateMode);
             
             this.NotifyOfPropertyChange(() => this.VideoTrackInfo);
 
@@ -648,7 +640,7 @@ namespace HandBrakeWPF.ViewModels
                 AudioTrack track1 = this.Task.AudioTracks[0];
                 HBMixdown mixdownName = HandBrakeEncoderHelpers.GetMixdown(track1.MixDown);
                 string mixdown = mixdownName != null ? ", " + mixdownName.DisplayName : string.Empty;
-                desc.AppendLine(string.Format("{0}{1}", EnumHelper<AudioEncoder>.GetDisplay(track1.Encoder), mixdown));
+                desc.AppendLine(string.Format("{0}{1}", track1.Encoder.DisplayName, mixdown));
             }
 
             if (this.Task.AudioTracks.Count >= 2)
@@ -656,7 +648,7 @@ namespace HandBrakeWPF.ViewModels
                 AudioTrack track2 = this.Task.AudioTracks[1];
                 HBMixdown mixdownName = HandBrakeEncoderHelpers.GetMixdown(track2.MixDown);
                 string mixdown = mixdownName != null ? ", " + mixdownName.DisplayName : string.Empty;
-                desc.AppendLine(string.Format("{0}{1}", EnumHelper<AudioEncoder>.GetDisplay(track2.Encoder), mixdown));
+                desc.AppendLine(string.Format("{0}{1}", track2.Encoder.DisplayName, mixdown));
             }
 
             if (this.Task.AudioTracks.Count > 2)
@@ -724,7 +716,6 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.FiltersInfo);
         }
 
-        [HandleProcessCorruptedStateExceptions]
         private void UpdatePreviewFrame()
         {
             // Don't preview for small images.
